---
url: https://www.normattiva.it/uri-res/N2Ls?urn:nir:stato:legge:1981-11-24;689
url_xml: https://www.normattiva.it/do/atto/caricaAKN?dataGU=19811130&codiceRedaz=081U0689&dataVigenza=20251104
dataGU: 19811130
codiceRedaz: 081U0689
dataVigenza: 20251104
---

# Modifiche al sistema penale.

La Camera dei deputati ed il Senato della Repubblica hanno

approvato;

IL PRESIDENTE DELLA REPUBBLICA

PROMULGA la seguente legge:

### LE SANZIONI AMMINISTRATIVE SEZIONE I PRINCIPI GENERALI

#### Art. 1. - Principio di legalit

Nessuno puo' essere assoggettato a sanzioni amministrative se non in forza di una legge che sia entrata in vigore prima della commissione della violazione. Le leggi che prevedono sanzioni amministrative si applicano soltanto nei casi e per i tempi in esse considerati.

#### Art. 2. - (Capacita' di intendere e di volere)

Non puo' essere assoggettato a sanzione amministrativa chi, al momento in cui ha commesso il fatto, non aveva compiuto i diciotto anni o non aveva, in base ai criteri indicati nel codice penale, la capacita' di intendere e di volere, salvo che lo stato di incapacita' non derivi da sua colpa o sia stato da lui preordinato. Fuori dei casi previsti dall'ultima parte del precedente comma, della violazione risponde chi era tenuto alla sorveglianza dell'incapace, salvo che provi di non aver potuto impedire il fatto.

#### Art. 3. - (Elemento soggettivo)

Nelle violazioni cui e' applicabile una sanzione amministrativa ciascuno e' responsabile della propria azione od omissione, cosciente e volontaria, sia essa dolosa o colposa. Nel caso in cui la violazione e' commessa per errore sul fatto, l'agente non e' responsabile quando l'errore non e' determinato da sua colpa.

#### Art. 4. - Cause di esclusione della responsabilit

Non risponde delle violazioni amministrative chi ha commesso il fatto nell'adempimento di un dovere o nell'esercizio di una facolta' legittima ovvero in stato di necessita' o di legittima difesa. Se la violazione e' commessa per ordine dell'autorita', della stessa risponde il pubblico ufficiale che ha dato l'ordine. ((I comuni, le province, le comunita' montane e i loro consorzi, le istituzioni pubbliche di assistenza e beneficenza (IPAB), gli enti non commerciali senza scopo di lucro che svolgono attivita' socio- assistenziale e le istituzioni sanitarie operanti nel Servizio sanitario nazionale ed i loro amministratori non rispondono delle sanzioni amministrative e civili che riguardano l'assunzione di lavoratori, le assicurazioni obbligatorie e gli ulteriori adempimenti, relativi a prestazioni lavorative stipulate nella forma del contratto d'opera e successivamente riconosciute come rapporti di lavoro subordinato, purche' esaurite alla data del 31 dicembre 1997)).

#### Art. 5. - (Concorso di persone)

Quando piu' persone concorrono in una violazione amministrativa, ciascuna di esse soggiace alla sanzione per questa disposta, salvo che sia diversamente stabilito dalla legge.

#### Art. 6. - Solidariet

Il proprietario della cosa che servi' o fu destinata a commettere la violazione o, in sua vece, l'usufruttuario o, se trattasi di bene immobile, il titolare di un diritto personale di godimento, e' obbligato in solido con l'autore della violazione al pagamento della somma da questo dovuta se non prova che la cosa e' stata utilizzata contro la sua volonta'. Se la violazione e' commessa da persona capace di intendere e di volere ma soggetta all'altrui autorita', direzione o vigilanza, la persona rivestita dell'autorita' o incaricata della direzione o della vigilanza e' obbligata in solido con l'autore della violazione al pagamento della somma da questo dovuta, salvo che provi di non aver potuto impedire il fatto. Se la violazione e' commessa dal rappresentante o dal dipendente di una persona giuridica o di un ente privo di personalita' giuridica o, comunque, di un imprenditore, nell'esercizio delle proprie funzioni o incombenze, la persona giuridica o l'ente o l'imprenditore e' obbligato in solido con l'autore della violazione al pagamento della somma da questo dovuta. Nei casi previsti dai commi precedenti chi ha pagato ha diritto di regresso per l'intero nei confronti dell'autore della violazione.

#### Art. 7. - (Non trasmissibilita' dell'obbligazione)

L'obbligazione di pagare la somma dovuta per la violazione non si trasmette agli eredi.

#### Art. 8. - (Piu' violazioni di disposizioni che prevedono sanzioni amministrative)

Salvo che sia diversamente stabilito dalla legge, chi con un'azione od omissione viola diverse disposizioni che prevedono sanzioni amministrative o commette piu' violazioni della stessa disposizione, soggiace alla sanzione prevista per la violazione piu' grave, aumentata sino al triplo. ((Alla stessa sanzione prevista dal precedente comma soggiace anche chi con piu' azioni od omissioni, esecutive di un medesimo disegno posto in essere in violazione di norme che stabiliscono sanzioni amministrative, commette, anche in tempi diversi, piu' violazioni della stessa o di diverse norme di legge in materia di previdenza ed assistenza obbligatorie. La disposizione di cui al precedente comma si applica anche alle violazioni commesse anteriormente all'entrata in vigore della legge di conversione del decreto-legge 2 dicembre 1985, n. 688, per le quali non sia gia' intervenuta sentenza passata in giudicato)).

#### Art. 8-bis. - (((Reiterazione delle violazioni). ))

(( Salvo quanto previsto da speciali disposizioni di legge, si ha reiterazione quando, nei cinque anni successivi alla commissione di una violazione amministrativa, accertata con provvedimento esecutivo, lo stesso soggetto commette un'altra violazione della stessa indole. Si ha reiterazione anche quando piu' violazioni della stessa indole commesse nel quinquennio sono accertate con unico provvedimento esecutivo. Si considerano della stessa indole le violazioni della medesima disposizione e quelle di disposizioni diverse che, per la natura dei fatti che le costituiscono o per le modalita' della condotta, presentano una sostanziale omogeneita' o caratteri fondamentali comuni. La reiterazione e' specifica se e' violata la medesima disposizione. Le violazioni amministrative successive alla prima non sono valutate, ai fini della reiterazione, quando sono commesse in tempi ravvicinati e riconducibili ad una programmazione unitaria. La reiterazione determina gli effetti che la legge espressamente stabilisce. Essa non opera nel caso di pagamento in misura ridotta. Gli effetti conseguenti alla reiterazione possono essere sospesi fino a quando il provvedimento che accerta la violazione precedentemente commessa sia divenuto definitivo. La sospensione e' disposta dall'autorita' amministrativa competente, o in caso di opposizione dal giudice, quando possa derivare grave danno. Gli effetti della reiterazione cessano di diritto, in ogni caso, se il provvedimento che accerta la precedente violazione e' annullato.))

#### Art. 9. - Principio di specialit

Quando uno stesso fatto e' punito da una disposizione penale e da una disposizione che prevede una sanzione amministrativa, ovvero da una pluralita' di disposizioni che prevedono sanzioni amministrative, si applica la disposizione speciale. Tuttavia quando uno stesso fatto e' punito da una disposizione penale e da una disposizione regionale o delle province autonome di Trento e di Bolzano che preveda una sanzione amministrativa, si applica in ogni caso la disposizione penale, salvo che quest'ultima sia applicabile solo in mancanza di altre disposizioni penali. ((Ai fatti puniti dagli articoli 5, 6 e 12 della legge 30 aprile 1962, n. 283, e successive modificazioni ed integrazioni, si applicano soltanto le disposizioni penali, anche quando i fatti stessi sono puniti con sanzioni amministrative previste da disposizioni speciali in materia di produzione, commercio e igiene degli alimenti e delle bevande.))

#### Art. 10. - (Sanzione amministrativa pecuniaria e rapporto tra limite minimo e limite massimo)

La sanzione amministrativa pecuniaria consiste nel pagamento di una somma ((non inferiore a euro 10)) e ((non superiore a euro 15.000)). Le sanzioni proporzionali non hanno limite massimo. Fuori dei casi espressamente stabiliti dalla legge, il limite massimo della sanzione amministrativa pecuniaria non puo', per ciascuna violazione, superare il decuplo del minimo.

#### Art. 11. - (Criteri per l'applicazione delle sanzioni ammistrative pecuniarie)

Nella determinazione della sanzione amministrativa pecuniaria fissata dalla legge tra un limite minimo ed un limite massimo e nell'applicazione delle sanzioni accessorie facoltative, si ha riguardo alla gravita' della violazione, all'opera svolta dall'agente per la eliminazione o attenuazione delle conseguenze della violazione, nonche' alla personalita' dello stesso e alle sue condizioni economiche.

#### Art. 12. - (Ambito di applicazione)

Le disposizioni di questo Capo si osservano, in quanto applicabili e salvo che non sia diversamente stabilito, per tutte le violazioni per le quali e' prevista la sanzione amministrativa del pagamento di una somma di denaro, anche quando questa sanzione non e' prevista in sostituzione di una sanzione penale. Non si applicano alle violazioni disciplinari.

## APPLICAZIONE

### Art. 13. - (Atti di accertamento)

Gli organi addetti al controllo sull'osservanza delle disposizioni per la cui violazione e' prevista la sanzione amministrativa del pagamento di una somma di denaro possono, per l'accertamento delle violazioni di rispettiva competenza, assumere informazioni e procedere a ispezioni di cose e di luoghi diversi dalla privata dimora, a rilievi segnaletici, descrittivi e fotografici e ad ogni altra operazione tecnica. Possono altresi' procedere al sequestro cautelare delle cose che possono formare oggetto di confisca amministrativa, nei modi e con i limiti con cui il codice di procedura penale consente il sequestro alla polizia giudiziaria. E' sempre disposto il sequestro del veicolo a motore o del natante posto in circolazione senza essere coperto dalla assicurazione obbligatoria e del veicolo posto in circolazione senza che per lo stesso sia stato rilasciato il documento di circolazione. All'accertamento delle violazioni punite con la sanzione amministrativa del pagamento di una somma di denaro possono procedere anche gli ufficiali e gli agenti di polizia giudiziaria, i quali, oltre che esercitare i poteri indicati nei precedenti commi, possono procedere, quando non sia possibile acquisire altrimenti gli elementi di prova, a perquisizioni in luoghi diversi dalla privata dimora, previa autorizzazione motivata del pretore del luogo ove le perquisizioni stesse dovranno essere effettuate. Si applicano le disposizioni del primo comma dell'articolo 333 e del primo e secondo comma dell'articolo 334 del codice di procedura penale. E' fatto salvo l'esercizio degli specifici poteri di accertamento previsti dalle leggi vigenti.

### Art. 14. - (Contestazione e notificazione)

La violazione, quando e possibile, deve essere contestata immediatamente tanto al trasgressore quanto alla persona che sia obbligata in solido al pagamento della somma dovuta per la violazione stessa. Se non e' avvenuta la contestazione immediata per tutte o per alcune delle persone indicate nel comma precedente, gli estremi della violazione debbono essere notificati agli interessati residenti nel territorio della Repubblica entro il termine di novanta giorni e a quelli residenti all'estero entro il termine di trecentosessanta giorni dall'accertamento. Quando gli atti relativi alla violazione sono trasmessi all'autorita' competente con provvedimento dell'autorita' giudiziaria, i termini di cui al comma precedente decorrono dalla data della ricezione. Per la forma della contestazione immediata o della notificazione si applicano le disposizioni previste dalle leggi vigenti. In ogni caso la notificazione puo' esse effettuata, con le modalita' previste dal codice di procedura civile, anche da un funzionario dell'amministrazione che ha accertato la violazione.((Quando la notificazione non puo' essere eseguita in mani proprie del destinatario, si osservano le modalita' previste dall'articolo 137, terzo comma, del medesimo codice.)) Per i residenti all'estero, qualora la residenza, la dimora o il domicilio non siano noti, la notifica non e' obbligatoria e resta salva la facolta' del pagamento in misura ridotta sino alla scadenza del termine previsto nel secondo comma dell'articolo 22 per il giudizio di opposizione. L'obbligazione di pagare la somma dovuta per la violazione si estingue per la persona nei cui confronti e' stata omessa la notificazione nel termine prescritto.

### Art. 15. - (Accertamenti mediante analisi di campioni)

Se per l'accertamento della violazione sono compiute analisi di campioni, il dirigente del laboratorio deve comunicare all'interessato, a mezzo di lettera raccomandata con avviso di ricevimento, l'esito dell'analisi. L'interessato puo' chiedere la revisione dell'analisi con la partecipazione di un proprio consulente tecnico. La richiesta e' presentata con istanza scritta all'organo che ha prelevato i campioni da analizzare, nel termine di quindici giorni dalla comunicazione dell'esito della prima analisi, che deve essere allegato all'istanza medesima. Delle operazioni di revisione dell'analisi e' data comunicazione all'interessato almeno dieci giorni prima del loro inizio. I risultati della revisione dell'analisi sono comunicati all'interessato a mezzo di lettera raccomandata con avviso di ricevimento, a cura del dirigente del laboratorio che ha eseguito la revisione dell'analisi. Le comunicazioni di cui al primo e al quarto comma equivalgono alla contestazione di cui al primo comma dell'articolo 14 ed il termine per il pagamento in misura ridotta di cui all'articolo 16 decorre dalla comunicazione dell'esito della prima analisi o, quando e' stata chiesta la revisione dell'analisi, dalla comunicazione dell'esito della stessa. Ove non sia possibile effettuare la comunicazione all'interessato nelle forme di cui al primo e al quarto comma, si applicano le disposizioni dell'articolo 14. Con il decreto o con la legge regionale indicati nell'ultimo comma dell'articolo 17 sara' altresi' fissata la somma di denaro che il richiedente la revisione dell'analisi e' tenuto a versare e potranno essere indicati, anche a modifica delle vigenti disposizioni di legge, gli istituti incaricati della stessa analisi.

### Art. 16. - (Pagamento in misura ridotta)

E' ammesso il pagamento di una somma in misura ridotta pari alla terza parte del massimo della sanzione prevista per la violazione commessa o, se piu favorevole e qualora sia stabilito il minimo della sanzione edittale, pari al doppio del relativo importo , oltre alle spese del procedimento, entro il termine di sessanta giorni dalla contestazione immediata o, se questa non vi e' stata, dalla notificazione degli estremi della violazione. ((45)) Per le violazioni ai regolamenti ed alle ordinanze comunali e provinciali, la Giunta comunale o provinciale, all'interno del limite edittale minimo e massimo della sanzione prevista, puo' stabilire un diverso importo del pagamento in misura ridotta, in deroga alle disposizioni del primo comma. Il pagamento in misura ridotta e' ammesso anche nei casi in cui le norme antecedenti all'entrata in vigore della presente legge non consentivano l'oblazione.(8)

----------- AGGIORNAMENTO (8) Il D.Lgs. 30 aprile 1992, n.285 (in S.O. n. 74, relativo alla G.U. 18/5/1992, n.114) ha disposto (con l'art.231) l'abrogazione legge 24 novembre 1981 n. 689 art. 16 secondo comma, per la parte relativa al testo unico delle norme sulla circolazione stradale, approvato con decreto del Presidente della Repubblica 15 giugno 1959, n. 393. ----------- AGGIORNAMENTO (45) Il D.Lgs. 10 agosto 2018, n. 101 ha disposto (con l'art. 18, comma 1) che "In deroga all'articolo 16 della legge 24 novembre 1981, n. 689, per i procedimenti sanzionatori riguardanti le violazioni di cui agli articoli 161, 162, 162-bis, 162-ter, 163, 164, 164-bis, comma 2, del Codice in materia di protezione dei dati personali, di cui al decreto legislativo 30 giugno 2003, n. 196, e le violazioni delle misure di cui all'articolo 33 e 162, comma 2-bis, del medesimo Codice, che, alla data di applicazione del Regolamento, risultino non ancora definiti con l'adozione dell'ordinanza-ingiunzione, e' ammesso il pagamento in misura ridotta di un somma pari a due quinti del minimo edittale. Fatti salvi i restanti atti del procedimento eventualmente gia' adottati, il pagamento potra' essere effettuato entro novanta giorni dalla data di entrata in vigore del presente decreto".

### Art. 17. - (Obbligo del rapporto)

Qualora non sia stato effettuato il pagamento in misura ridotta, il funzionario o l'agente che ha accertato la violazione, salvo che ricorra l'ipotesi prevista nell'articolo 24, deve presentare rapporto, con la prova delle eseguite contestazioni o notificazioni, all'ufficio periferico cui sono demandati attribuzioni e compiti del Ministero nella cui competenza rientra la materia alla quale si riferisce la violazione o, in mancanza, al prefetto. Deve essere presentato al prefetto il rapporto relativo alle violazioni previste dal testo unico delle norme sulla circolazione stradale, approvato con decreto del Presidente della Repubblica 15 giugno 1959, n. 393, dal testo unico per la tutela delle strade, approvato con regio decreto 8 dicembre 1933, numero 1740, e dalla legge 20 giugno 1935, numero 1349, sui servizi di trasporto merci. Nelle materie di competenza delle regioni e negli altri casi, per le funzioni amministrative ad esse delegate, il rapporto e' presentato all'ufficio regionale competente. Per le violazioni dei regolamenti provinciali e comunali il rapporto e' presentato, rispettivamente, al presidente della giunta provinciale o al sindaco. L'ufficio territorialmente competente e' quello del luogo in cui e' stata commessa la violazione. ((40)) Il funzionario o l'agente che ha proceduto al sequestro previsto dall'articolo 13 deve immediatamente informare l'autorita' amministrativa competente a norma dei precedenti commi, inviandole il processo verbale di sequestro. Con decreto del Presidente della Repubblica, su proposta del Presidente del Consiglio dei ministri, da emanare entro centottanta giorni dalla pubblicazione della presente legge, in sostituzione del decreto del Presidente della Repubblica 13 maggio 1976, n. 407, saranno indicati gli uffici periferici dei singoli Ministeri, previsti nel primo comma, anche per i casi in cui leggi precedenti abbiano regolato diversamente la competenza. Con il decreto indicato nel comma precedente saranno stabilite le modalita' relative alla esecuzione del sequestro previsto dall'articolo 13, al trasporto ed alla consegna delle cose sequestrate, alla custodia ed alla eventuale alienazione o distruzione delle stesse; sara' altresi' stabilita la destinazione delle cose confiscate. Le regioni, per le materie di loro competenza, provvederanno con legge nel termine previsto dal comma precedente.

-------------- AGGIORNAMENTO (40) La L. 13 agosto 2010, n. 136, come modificata dal D.L. 12 novembre 2010, n. 187, convertito con modificazioni dalla L. 17 dicembre 2010, n. 217, ha disposto (con l'art. 6, comma 5) che "In deroga a quanto previsto dall'articolo 17, quinto comma, della legge 24 novembre 1981, n. 689, le sanzioni amministrative pecuniarie per le violazioni di cui ai precedenti commi sono applicate dal prefetto della provincia ove ha sede la stazione appaltante o l'amministrazione concedente".

### Art. 18. - (Ordinanza-ingiunzione)

Entro il termine di trenta giorni dalla data della contestazione o notificazione della violazione, gli interessati possono far pervenire all'autorita' competente a ricevere il rapporto a norma dell'articolo 17 scritti difensivi e documenti e possono chiedere di essere sentiti dalla medesima autorita'. L'autorita' competente, sentiti gli interessati, ove questi ne abbiano fatto richiesta, ed esaminati i documenti inviati e gli argomenti esposti negli scritti difensivi, se ritiene fondato l'accertamento, determina, con ordinanza motivata, la somma dovuta per la violazione e ne ingiunge il pagamento, insieme con le spese, all'autore della violazione ed alle persone che vi sono obbligate solidalmente; altrimenti emette ordinanza motivata di archiviazione degli atti comunicandola integralmente all'organo che ha redatto il rapporto. Con l'ordinanza-ingiunzione deve essere disposta la restituzione, previo pagamento delle spese di custodia, delle cose sequestrate, che non siano confiscate con lo stesso provvedimento. La restituzione delle cose sequestrate e' altresi' disposta con l'ordinanza di archiviazione, quando non ne sia obbligatoria la confisca. Il pagamento e' effettuato all'ufficio del registro o al diverso ufficio indicato nella ordinanza-ingiunzione, entro il termine di trenta giorni dalla notificazione di detto provvedimento, eseguita nelle forme previste dall'articolo 14; del pagamento e' data comunicazione, entro il trentesimo giorno, a cura dell'ufficio che lo ha ricevuto, all'autorita' che ha emesso l'ordinanza. Il termine per il pagamento e' di sessanta giorni se l'interessato risiede all'estero. ((La notificazione dell'ordinanza-ingiunzione puo' essere eseguita dall'ufficio che adotta l'atto, secondo le modalita' di cui alla legge 20 novembre 1982, n.890)). L'ordinanza-ingiunzione costituisce titolo esecutivo. Tuttavia l'ordinanza che dispone la confisca diventa esecutiva dopo il decorso del termine per proporre opposizione, o, nel caso in cui l'opposizione e' proposta, con il passaggio in giudicato della sentenza con la quale si rigetta l'opposizione, o quando l'ordinanza con la quale viene dichiarata inammissibile l'opposizione o convalidato il provvedimento opposto diviene inoppugnabile o e' dichiarato inammissibile il ricorso proposto avverso la stessa.

### Art. 19. - (Sequestro)

Quando si e' proceduto a sequestro, gli interessati possono, anche immediatamente, proporre opposizione all'autorita' indicata nel primo comma dell'artico 18, con atto esente da bollo. Sull'opposizione a decisione e' adottata con ordinanza motivata emessa entro il decimo giorno successivo alla sua proposizione. Se non e' rigettata entro questo termine, l'opposizione si intende accolta. Anche prima che sia concluso il procedimento amministrativo l'autorita' competentente puo' disporre la restituzione della cosa sequestrata, previo pagamento delle spese di custodia, a chi prova di averne diritto e ne fa istanza, salvo che si tratti di cose soggette a confisca obbligatoria. Quando l'opposizione al sequestro e' stata rigettata, il sequestro cessa di avere efficacia se non e' emessa ordinanza-ingiunzione di pagamento o se non e' disposta la confisca entro due mesi dal giorno in cui e' pervenuto il rapporto e, comunque, entro sei mesi dal giorno in cui e' avvenuto il sequestro. ((44))

------------- AGGIORNAMENTO (44) Il D.L. 24 giugno 2014, n. 91 convertito con modificazioni dalla L. 11 agosto 2014, n. 116 ha disposto (con l'art. 4, comma 4) che "La procedura prevista dall'articolo 19 della legge 24 novembre 1981, n. 689, si applica anche all'opposizione all'inibizione all'uso della denominazione protetta".

### Art. 20. - (Sanzioni amministrative accessorie)

L'autorita' amministrativa con l'ordinanza - ingiunzione o il giudice penale con la sentenza di condanna nel caso previsto dall'articolo 24, puo' applicare, come sanzioni amministrative, quelle previste dalle leggi vigenti, per le singole violazioni, come sanzioni penali accessorie, quando esse consistono nella privazione o sospensione di facolta' e diritti derivanti da provvedimenti dell'amministrazione. Le sanzioni amministrative accessorie non sono applicabili fino a che e' pendente il giudizio di opposizione contro il provvedimento di condanna o, nel caso di connessione di cui all'articolo 24, fino a che il provvedimento stesso non sia divenuto esecutivo. Le autorita' stesse possono disporre la confisca amministrativa delle cose che servirono o furono destinate a commettere la violazione e debbono disporre la confisca delle cose che ne sono il prodotto, sempre che le cose suddette appartengano a una delle persone cui e' ingiunto il pagamento. ((In presenza di violazioni gravi o reiterate, in materia di tutela del lavoro, di igiene sui luoghi di lavoro e di prevenzione degli infortuni sul lavoro, e' sempre disposta la confisca amministrativa delle cose che servirono o furono destinate a commettere la violazione e delle cose che ne sono il prodotto, anche se non venga emessa l'ordinanza - ingiunzione di pagamento. La disposizione non si applica se la cosa appartiene a persona estranea alla violazione amministrativa ovvero quando in relazione ad essa e' consentita la messa a norma e quest'ultima risulta effettuata secondo le disposizioni vigenti.)) E' sempre disposta la confisca amministrativa delle cose, la fabbricazione, l'uso, il porto, la detenzione o l'alienazione delle quali costituisce violazione amministrativa, anche se non venga emessa l'ordinanza-ingiunzione di pagamento. La disposizione indicata nel comma precedente non si applica se la cosa appartiene a persona estranea alla violazione amministrativa e la fabbricazione, l'uso, il porto, la detenzione o l'alienazione possono essere consentiti mediante autorizzazione amministrativa.

### Art. 21. - (Casi speciali di sanzioni amministrative accessorie)

Quando e' accertata la violazione del primo comma dell'articolo 32 della legge 24 dicembre 1969, n. 990, e' sempre disposta la confisca del veicolo a motore o del natante che appartiene alla persona a cui e' ingiunto il pagamento, se entro il termine fissato con l'ordinanza-ingiunzione non viene pagato, oltre alla sanzione pecuniaria applicata, anche il premio di assicurazione per almeno sei mesi. Nel caso in cui sia proposta opposizione avverso l'ordinanza-ingiunzione, il termine di cui al primo comma decorre dal passaggio in giudicato della sentenza con la quale si rigetta l'opposizione ovvero dal momento in cui diventa inoppugnabile l'ordinanza con la quale viene dichiarata inammissibile l'opposizione o convalidato il provvedimento opposto ovvero viene dichiarato inammissibile il ricorso proposto avverso la stessa. Quando e' accertata la violazione dell'ottavo comma dell'articolo 58 del testo unico delle norme sulla circolazione stradale, approvato con decreto del Presidente della Repubblica 15 giugno 1959, n. 393, e' sempre disposta la confisca del veicolo.((14)) Quando e' accertata la violazione del secondo comma dell'articolo 14 della legge 30 aprile 1962, n. 283, e' sempre disposta la sospensione della licenza per un periodo non superiore a dieci giorni.

------------ AGGIORNAMENTO (14) La Corte Costituzionale con sentenza 24-27 ottobre, n.371 (in G.U. 1a s.s. 2/1/1994, n.45) ha dichiarato "l'illegittimita' costituzionale dell'art. 21, terzo comma, della legge 24 novembre 1981, n. 689 (Modifiche al sistema penale), nella parte in cui prevede la confisca del veicolo privo della carta di circolazione, anche se gia' immatricolato."

### Art. 22. - (Opposizione all'ordinanza-ingiunzione)

((Salvo quanto previsto dall'articolo 133 del decreto legislativo 2 luglio 2010, n. 104, e da altre disposizioni di legge, contro l'ordinanza-ingiunzione di pagamento e contro l'ordinanza che dispone la sola confisca gli interessati possono proporre opposizione dinanzi all'autorita' giudiziaria ordinaria. L'opposizione e' regolata dall'articolo 6 del decreto legislativo 1° settembre 2011, n. 150.)) ((42)) ((COMMA ABROGATO DAL D.LGS. 1 SETTEMBRE 2011, N. 150)). ((42)) ((COMMA ABROGATO DAL D.LGS. 1 SETTEMBRE 2011, N. 150)). ((42)) ((COMMA ABROGATO DAL D.LGS. 1 SETTEMBRE 2011, N. 150)). ((42)) ((COMMA ABROGATO DAL D.LGS. 1 SETTEMBRE 2011, N. 150)). ((42)) ((COMMA ABROGATO DAL D.LGS. 1 SETTEMBRE 2011, N. 150)). ((42)) ((COMMA ABROGATO DAL D.LGS. 1 SETTEMBRE 2011, N. 150)). ((42))

------------- AGGIORNAMENTO (7) La Corte Costituzionale con sentenza 5-24 febbraio 1992, n.62 (in G.U. 1a s.s. 4/3/1992, n.10) ha dichiarato " l'illegittimita' costituzionale degli artt. 22 e 23 della legge 24 novembre 1981, n. 689 (Modifiche al sistema penale), in combinato disposto con l'art. 122 c.p.c., nella parte in cui non consentono ai cittadini italiani appartenenti alla minoranza linguistica slovena nel processo di opposizione ad ordinanze-ingiunzioni applicative di sanzioni amministrative davanti al pretore avente competenza su un territorio dove sia insediata la predetta minoranza, di usare, su loro richiesta, la lingua materna nei propri atti, usufruendo per questi della traduzione nella lingua italiana, nonche' di ricevere tradotti nella propria lingua gli atti dell'autorita' giudiziaria e le risposte della controparte." ------------- AGGIORNAMENTO (28) Il D.Lgs. 30 dicembre 1999, n.507 (in S.O. n.233 relativo alla G.U. 31/12/1999, n.306) ha disposto 8con l'art.97 comma 1) che:" L'articolo 22 della legge 24 novembre 1981, n. 689 e' cosi' modificato: a) nel primo comma le parole "davanti al giudice del luogo in cui e' stata commessa la violazione" sono sostituite dalle seguenti: "davanti al giudice del luogo in cui e' stata commessa la violazione individuato a norma dell'articolo 22-bis"." ------------- AGGIORNAMENTO (32a) La Corte Costituzionale con sentenza 10 - 18 marzo 2004, n.98 (in G.U. 1a s.s. 24/3/2004, n.12) ha dichiarato "l'illegittimita' costituzionale dell'art. 22 della legge 24 novembre 1981, n. 689 (Modifiche al sistema penale), nella parte in cui non consente l'utilizzo del servizio postale per la proposizione dell'opposizione". ------------- AGGIORNAMENTO (40) La L. 13 agosto 2010, n. 136, come modificata dal D.L. 12 novembre 2010, n. 187, convertito con modificazioni dalla L. 17 dicembre 2010, n. 217, ha disposto (con l'art. 6, comma 5) che "in deroga a quanto previsto dall'articolo 22, primo comma, della citata legge n. 689 del 1981, l'opposizione e' proposta davanti al giudice del luogo ove ha sede l'autorita' che ha applicato la sanzione". ---------------- AGGIORNAMENTO (42) Il D.Lgs. 1 settembre 2011, n. 150 ha disposto (con l'art. 36, commi 1 e 2) che "1. Le norme del presente decreto si applicano ai procedimenti instaurati successivamente alla data di entrata in vigore dello stesso. 2. Le norme abrogate o modificate dal presente decreto continuano ad applicarsi alle controversie pendenti alla data di entrata in vigore dello stesso."

### Art. 22-bis.

((ARTICOLO ABROGATO DAL D.LGS. 1 SETTEMBRE 2011, N. 150)) ((42)) ---------------- AGGIORNAMENTO (42) Il D.Lgs. 1 settembre 2011, n. 150 ha disposto (con l'art. 36, commi 1 e 2) che "1. Le norme del presente decreto si applicano ai procedimenti instaurati successivamente alla data di entrata in vigore dello stesso. 2. Le norme abrogate o modificate dal presente decreto continuano ad applicarsi alle controversie pendenti alla data di entrata in vigore dello stesso."

### Art. 23.

((ARTICOLO ABROGATO DAL D.LGS. 1 SETTEMBRE 2011, N. 150)) ((42)) ---------------- AGGIORNAMENTO (42) Il D.Lgs. 1 settembre 2011, n. 150 ha disposto (con l'art. 36, commi 1 e 2) che "1. Le norme del presente decreto si applicano ai procedimenti instaurati successivamente alla data di entrata in vigore dello stesso. 2. Le norme abrogate o modificate dal presente decreto continuano ad applicarsi alle controversie pendenti alla data di entrata in vigore dello stesso."

### Art. 24. - (Connessione obiettiva con un reato)

Qualora l'esistenza di un reato dipenda dall'accertamento di una violazione non costituente reato, e per questa non sia stato effettuato il pagamento in misura ridotta, il giudice penale competente a conoscere del reato e' pure competente a decidere sulla predetta violazione e ad applicare con la sentenza di condanna la sanzione stabilita dalla legge per la violazione stessa. Se ricorre l'ipotesi prevista dal precedente comma, il rapporto di cui all'articolo 17 e' trasmesso, anche senza che si sia proceduto alla notificazione prevista dal secondo comma dell'articolo 14, alla autorita' giudiziaria competente per il reato, la quale, quando invia la comunicazione giudiziaria, dispone la notifica degli estremi della violazione amministrativa agli obbligati per i quali essa non e' avvenuta. Dalla notifica decorre il termine per il pagamento in misura ridotta. Se l'autorita' giudiziaria non procede ad istruzione, il pagamento in misura ridotta puo' essere effettuato prima dell'apertura del dibattimento. La persona obbligata in solido con l'autore della violazione deve essere citata nella istruzione o nel giudizio penale su richiesta del pubblico ministero. Il pretore ne dispone di ufficio la citazione. Alla predetta persona, per la difesa dei propri interessi, spettano i diritti e le garanzie rconosciuti all'imputato, esclusa la nomina del difensore d'ufficio. Il pretore, quando provvede con decreto penale, con lo stesso decreto applica, nei confronti dei responsabili, la sanzione stabilita dalla legge per la violazione. La competenza del giudice penale in ordine alla violazione non costituente reato cessa se il procedimento penale si chiude per estinzione del reato o per difetto di una condizione di procedibilita'.

### Art. 25. - (Impugnabilita' del provvedimento del giudice penale)

La sentenza del giudice penale, relativamente al capo che, ai sensi dell'articolo precedente, decide sulla violazione non costituente reato, e' impugnabile, oltre che dall'imputato e dal pubblico ministero, anche dalla persona che sia stata solidalmente condannata al pagamento della somma dovuta per la violazione. Avverso il decreto penale, relativamente al capo che dichiara la responsabilita' per la predetta violazione, puo' proporre opposizione anche la persona indicata nel comma precedente. Si osservano, in quanto applicabili, le disposizioni del codice di procedura penale concernenti l'impugnazione per i soli interessi civili.

### Art. 26. - (Pagamento rateale della sanzione pecuniaria)

L'autorita' giudiziaria o amministrativa che ha applicato la sanzione pecuniaria puo' disporre, su richiesta dell'interessato che si trovi in condizioni economiche disagiate, che la sanzione medesima venga pagata in rate mensili da tre a trenta; ciascuna rata non puo' essere inferiore a lire trentamila. In ogni momento il debito puo' essere estinto mediante un unico pagamento. Decorso inutilmente, anche per una sola rata, il termine fissato dall'autorita' giudiziaria o amministrativa, l'obbligato e' tenuto al pagamento del residuo ammontare della sanzione in un'unica soluzione.

### Art. 27. - (Esecuzione forzata)

Salvo quanto disposto nell'ultimo comma dell'articolo 22, decorso inutilmente il termine fissato per il pagamento, l'autorita' che ha emesso l'ordinanza-ingiunzione procede alla riscossione delle somme dovute in base alle norme previste per la esazione delle imposte dirette, trasmettendo il ruolo all'intendenza di finanza che lo da' in carico all'esattore per la riscossione in unica soluzione, senza l'obbligo del non riscosso come riscosso. E' competente l'intendenza di finanza del luogo ove ha sede l'autorita' che ha emesso l'ordinanza-ingiunzione. Gli esattori, dopo aver trattenuto l'aggio nella misura ridotta del 50 per cento rispetto a quella ordinaria e comunque non superiore al 2 per cento delle somme riscosse, effettuano il versamento delle somme medesime ai destinatari dei proventi. Le regioni possono avvalersi anche delle procedure previste per la riscossione delle proprie entrate. Se la somma e' dovuta in virtu' di una sentenza o di un decreto penale di condanna ai sensi dell'articolo 24, si procede alla riscossione con l'osservanza delle norme sul recupero delle spese processuali. Salvo quanto previsto nell'articolo 26, in caso di ritardo nel pagamento la somma dovuta e' maggiorata di un decimo per ogni semestre a decorrere da quello in cui la sanzione e' divenuta esigibile e fino a quello in cui il ruolo e' trasmesso all'esattore. La maggiorazione assorbe gli interessi eventualmente previsti dalle disposizioni vigenti.((Per le sanzioni amministrative per violazione delle disposizioni del codice della strada, di cui al decreto legislativo 30 aprile 1992, n. 285, la maggiorazione non puo' comunque essere superiore ai tre quinti dell'importo della sanzione)). Le disposizioni relative alla competenza dell'esattore si applicano fino alla riforma del sistema di riscossione delle imposte dirette.

### Art. 28. - (Prescrizione)

Il diritto a riscuotere le somme dovute per le violazioni indicate dalla presente legge si prescrive nel termine di cinque anni dal giorno in cui e' stata commessa la violazione. L'interruzione della prescrizione e' regolata dalle norme del codice civile.

### Art. 29. - (Devoluzione dei proventi)

I proventi delle sanzioni sono devoluti agli enti a cui era attribuito, secondo le leggi anteriori, l'ammontare della multa o dell'ammenda. Il provento delle sanzioni per le violazioni previste dalla legge 20 giugno 1935, n. 1349, sui servizi di trasporto merci, e' devoluto allo Stato. Nei casi previsti dal terzo comma dell'articolo 17 i proventi spettano alle regioni. Continuano ad applicarsi, se previsti, i criteri di ripartizione attualmente vigenti. Sono tuttavia escluse dalla ripartizione le autorita' competenti ad emanare l'ordinanza-ingiunzione di pagamento e la quota loro spettante e' ripartita tra gli altri aventi diritto, nella proporzione attribuita a ciascuno di essi.

### Art. 30. - (Valutazione delle violazioni in materia di circolazione stradale)

Agli effetti della sospensione e della revoca della patente di guida e del documento di circolazione, si tiene conto anche delle violazioni non costituenti reato previste, rispettivamente, dalle norme del testo unico sulla circolazione stradale, approvato con decreto del Presidente della Repubblica 15 giugno 1959, n. 393, e dalle norme della legge 20 giugno 1935, n. 1349, sui servizi di trasporto merci. Per le stesse violazioni, il prefetto dispone la sospensione della patente di guida o del documento di circolazione, quando ne ricorrono le condizioni, anche se e' avvenuto il pagamento in misura ridotta. Il provvedimento di sospensione e' revocato, qualora l'autorita' giudiziaria, pronunziando ai sensi degli articoli 23, 24 e 25, abbia escluso la responsabilita' per la violazione. Nei casi sopra previsti e in ogni altro caso di revoca o sospensione del documento di circolazione da parte del prefetto o di altra autorita', il provvedimento e' immediatamente comunicato al competente ufficio provinciale della motorizzazione civile.

### Art. 31. - (Provvedimenti dell'autorita' regionale)

I provvedimenti emessi dall'autorita' regionale per l'applicazione della sanzione amministrativa del pagamento di una somma di danaro non sono soggetti al controllo della Commissione prevista dall'articolo 41 della legge 10 febbraio 1953, n. 62. L'opposizione contro l'ordinanza-ingiunzione e' regolata dagli articoli 22 e 23.

## DEPENALIZZAZIONE DI DELITTI E CONTRAVVENZIONI

### Art. 32. - (Sostituzione della sanzione amministrativa pecuniaria alla multa o alla ammenda)

Non costituiscono reato e sono soggette alla sanzione amministrativa del pagamento di una somma di denaro tutte le violazioni per le quali e' prevista la sola pena della multa o dell'ammenda, salvo quanto disposto, per le violazioni finanziarie, dall'articolo 39. La disposizione del precedente comma non si applica ai reati in esso previsti che, nelle ipotesi aggravate, siano punibili con pena detentiva, anche se alternativa a quella pecuniaria. La disposizione del primo comma non si applica, infine, ai delitti in esso previsti che siano punibili a querela.

### Art. 33. - (Altri casi di depenalizzazione)

Non costituiscono reato e sono soggette alla sanzione amministrativa del pagamento di una somma di denaro le contravvenzioni previste: a) dagli articoli 669, 672, 687, 693 e 694 del codice penale; b) dagli articoli 121 e 124 del testo unico delle leggi di pubblica sicurezza, approvato con regio decreto 18 giugno 1931, numero 773, nella parte non abrogata dall'articolo 14 della legge 19 maggio 1976, n. 398; c) dagli articoli 121, 180, 181 e 186 del regolamento di pubblica sicurezza, approvato con regio decreto 6 maggio 1940, n. 635; d) dagli articoli 8, 58, comma ottavo, 72, 83, comma sesto, 88, comma sesto, del testo unico delle norme sulla circolazione stradale, approvato con decreto del Presidente della Repubblica 15 giugno 1959, n. 393, come modificati dalle leggi 14 febbraio 1974, n. 62, e 14 agosto 1974, n. 394, nonche' dal decreto-legge 11 agosto 1975, n. 367, convertito, con modificazioni, nella legge 10 ottobre 1975, n. 486; e) dal primo comma dell'articolo 32 della legge 24 dicembre 1969, n. 990, sull'assicurazione obbligatoria della responsabilita' civile derivante dalla circolazione dei veicoli a motore e dei natanti.

### Art. 34. - (Esclusione della depenalizzazione)

La disposizione del primo comma dell'articolo 32 non si applica ai reati previsti: a) dal codice penale, salvo quanto disposto dall'articolo 33, lettera a); b) dall'articolo 19, secondo comma, della legge 22 maggio 1978, n. 194, sulla interruzione volontaria della gravidanza; c) da disposizioni di legge concernenti le armi, le munizioni e gli esplosivi; d) dall'articolo 221 del testo unico delle leggi sanitarie, approvato con regio decreto 27 luglio 1934, n. 1265; e) dalla legge 30 aprile 1962, n. 283, modificata con legge 26 febbraio 1963, n. 441, sulla disciplina igienica degli alimenti, salvo che per le contravvenzioni previste dagli articoli 8 e 14 della stessa legge 30 aprile 1962, n. 283; f) dalla legge 29 marzo 1951, n. 327, sulla disciplina degli alimenti per la prima infanzia e dei prodotti dietetici; g) dalla legge 10 maggio 1976, n. 319, sulla tutela delle acque dall'inquinamento; h) dalla legge 13 luglio 1966, n. 615, concernente provvedimenti contro l'inquinamento atmosferico; i) dalla legge 31 dicembre 1962, n. 1860, e dal decreto del Presidente della Repubblica 13 febbraio 1964, n. 185, relativi all'impiego pacifico dell'energia nucleare; l) dalle leggi in materia urbanistica ed edilizia; m) dalle leggi relative ai rapporti di lavoro, anche per quanto riguarda l'assunzione dei lavoratori e le assicurazioni sociali, salvo quanto previsto dal successivo articolo 35; n) dalle leggi relative alla prevenzione degli infortuni sul lavoro ed all'igiene del lavoro; o) dall'articolo 108 del decreto del Presidente della Repubblica 30 marzo 1957, n. 361, e dall'articolo 89 del decreto del Presidente della Repubblica 16 maggio 1960 n. 570, in materia elettorale.

### Art. 35. - (Violazioni in materia di previdenza ed assistenza obbligatorie)

Non costituiscono reato e sono soggette alla sanzione amministrativa del pagamento di una somma di denaro tutte le violazioni previste dalle leggi in materia di previdenza ed assistenza obbligatorie, punite con la sola ammenda. Per le violazioni consistenti nell'omissione totale o parziale del versamento di contributi e premi, l'ordinanza-ingiunzione e' emessa, ai sensi dell'articolo 18, dagli enti ed istituti gestori delle forme di previdenza ed assistenza obbligatorie, che con lo stesso provvedimento ingiungono ai debitori anche il pagamento dei contributi e dei premi non versati e delle somme aggiuntive previste dalle leggi vigenti a titolo di sanzione civile. Per le altre violazioni, quando viene accertato che da esse deriva l'omesso o parziale versamento di contributi e premi, la relativa sanzione amministrativa e' applicata con la medesima ordinanza e dagli stessi enti ed istituti di cui al comma precedente. Avverso l'ordinanza-ingiunzione puo' essere proposta, nel termine previsto dall'articolo 22, opposizione davanti al pretore in funzione di giudice del lavoro. Si applicano i commi terzo e settimo dell'articolo 22 e il quarto comma dell'articolo 23 ed il giudizio di opposizione e' regolato ai sensi degli articoli 442 e seguenti del codice di procedura civile. Si osservano, in ogni caso, gli articoli 13, 14, 20, 24, 25, 26, 27, 28, 29 e 38 in quanto applicabili. ((IL D.LGS. 24 MARZO 2025, N. 33 HA CONFERMATO L'ABROGAZIONE DEL PRESENTE PERIODO)). L'ordinanza-ingiunzione emanata ai sensi del secondo comma costituisce titolo per iscrivere ipoteca legale sui beni del debitore, nei casi in cui essa e' consentita, quando la opposizione non e' stata proposta ovvero e' stata dichiarata inammissibile o rigettata. In pendenza del giudizio di opposizione la iscrizione dell'ipoteca e' autorizzata dal pretore se vi e' pericolo nel ritardo. Per le violazioni previste dal primo comma che non consistono nell'omesso o parziale versamento di contributi e premi e che non sono allo stesso connesse a norma del terzo comma si osservano le disposizioni delle sezioni I e II di questo Capo, in quanto applicabili. La disposizione del primo comma non si applica alle violazioni previste dagli articoli 53, 54, 139, 157, 175 e 246 del testo unico delle disposizioni per l'assicurazione obbligatoria contro gli infortuni sul lavoro e le malattie professionali, approvato con decreto del Presidente della Repubblica 30 giugno 1965, n. 1124. ((IL D.LGS. 24 MARZO 2025, N. 33 HA CONFERMATO L'ABROGAZIONE DEL PRESENTE COMMA)).

### Art. 36. - (Omissione o ritardo nel versamento di contributi e premi in materia di previdenza ed assistenza obbligatorie)

La sanzione amministrativa per l'omissione totale o parziale del versamento di contributi e premi in materia assistenziale e previdenziale non si applica se il pagamento delle somme dovute avviene entro trenta giorni dalla scadenza ovvero se, entro lo stesso termine, il datore di lavoro presenta domanda di dilazione all'ente o istituto di cui al secondo comma dell'articolo precedente. Tuttavia, quando e' stata presentata domanda di dilazione, la sanzione amministrativa si applica se il datore di lavoro: a) omette anche un solo versamento alla scadenza fissata dall'ente o istituto; b) non provvede al pagamento delle somme dovute entro venti giorni dalla comunicazione del rigetto della domanda di dilazione. Per gli effetti previsti dalla lettera b) del precedente comma la mancata comunicazione dell'accoglimento della domanda di dilazione entro novanta giorni dalla sua presentazione equivale a rigetto della medesima.

### Art. 37. - (((Omissione o falsita' di registrazione o denuncia obbligatorie) ))

((

1. Salvo che il fatto costituisca piu' grave reato, il datore di lavoro che, al fine di non versare in tutto o in parte contributi e premi previsti dalle leggi sulla previdenza e assistenza obbligatorie, omette una o piu' registrazioni o denunce obbligatorie, ovvero esegue una o piu' denunce obbligatorie in tutto o, in, parte, non conformi al vero, e' punito con la reclusione fino a due anni quando dal fatto deriva l'omesso versamento di contributi e premi previsti dalle leggi sulla previdenza e assistenza obbligatorie per un importo mensile non inferiore al maggiore importo fra cinque milioni mensili e il cinquanta per cento dei contributi complessivamente dovuti.

2. Fermo restando l'obbligo dell'organo di vigilanza di riferire al pubblico ministero la notizia di reato, qualora l'evasione accertata formi oggetto di ricorso amministrativo o giudiziario il procedimento penale e' sospeso dal momento dell'iscrizione della notizia di reato nel registro di cui all'articolo 335 del codice di procedura penale, fino al momento della decisione dell'organo amministrativo o giudiziario di primo grado.

3. La regolarizzazione dell'inadempienza accertata, anche attraverso dilazione, estingue il reato.

4. Entro novanta giorni l'ente impositore e' tenuto a dare comunicazione all'autorita' giudiziaria dell'avvenuta regolarizzazione o dell'esito del ricorso amministrativo o giudiziario))

### Art. 38. - (Entita' della somma dovuta)

La somma dovuta ai sensi del primo comma dell'articolo 32 e' pari all'ammontare della multa o dell'ammenda stabilita dalle disposizioni che prevedono le singole violazioni. La somma dovuta come sanzione amministrativa e' da lire ventimila a lire cinquecentomila per la violazione dell'articolo 669 del codice penale e da lire cinquantamila a lire cinquecentomila per la violazione dell'articolo 672 del codice penale. ((COMMA ABROGATO DAL D.LGS 13 LUGLIO 1994, N.480)). ((13)) La somma dovuta e' da lire duecentomila a lire due milioni per la violazione degli articoli 8, 58, comma ottavo, 72 e 83, comma sesto, da lire centomila a lire cinquecentomila per la violazione dell'articolo 88, comma sesto, del testo unico delle norme sulla circolazione stradale. La somma dovuta e' da lire centomila a lire un milione per la violazione dell'articolo 8 della legge 30 aprile 1962, n. 283, e da lire cinquantamila a lire duecentomila per la violazione dell'ultimo comma dell'articolo 14 della stessa legge. La somma dovuta e' da lire cinquecentomila a lire tre milioni per la violazione del primo comma dell'articolo 32 della legge 24 dicembre 1969, n. 990.

--------------- AGGIORNAMENTO (13) Il D.Lgs. 13 luglio 1994, n. 480 ha disposto (con l'art. 14, comma 1) che "Le disposizioni del presente decreto legislativo si applicano anche alle violazioni commesse anteriormente alla data di entrata in vigore determinata dall'art. 15, salvo che il relativo procedimento penale sia stato definito".

### Art. 39. - (Violazioni finanziarie)

Non costituiscono reato e sono soggette alla sanzione amministrativa del pagamento di una somma di denaro le violazioni previste da leggi in materia finanziaria punite solo con la multa o con l'ammenda. Se le leggi in materia finanziaria prevedono, oltre all'ammenda o alla multa, una pena pecuniaria, l'ammontare di quest'ultima si aggiunge alla somma prevista nel comma precedente e la sanzione viene unificata a tutti gli effetti. COMMA ABROGATO DAL D.LGS. 18 DICEMBRE 1997, N.472. COMMA ABROGATO DAL D.LGS. 18 DICEMBRE 1997, N.472. COMMA ABROGATO DAL D.LGS. 18 DICEMBRE 1997, N.472 Alle violazioni finanziarie, comprese quelle originariamente punite con la pena pecuniaria, si applicano, altresi', gli articoli ((...)), 29 e 38, primo comma. ((49))

---------------- AGGIORNAMENTO (49) Il D.Lgs. 5 novembre 2024, n. 173 ha disposto (con l'art. 102, comma 1) che "Le disposizioni del presente testo unico si applicano a decorrere dal 1° gennaio 2026".

## DISPOSIZIONI TRANSITORIE E FINALI

### Art. 40. - (Violazioni commesse anteriormente alla legge di depenalizzazione)

Le disposizioni di questo Capo si applicano anche alle violazioni commesse anteriormente all'entrata in vigore della presente legge che le ha depenalizzate, quando il relativo procedimento penale non sia stato definito.

### Art. 41. - (Norme processuali transitorie)

L'autorita' giudiziaria, in relazione ai procedimenti penali per le violazioni non costituenti piu' reato, pendenti alla data di entrata in vigore della presente legge, se non deve pronunciare decreto di archiviazione o sentenza di proscioglimento, dispone la trasmissione degli atti all'autorita' competente. Da tale momento decorre il termine di cui al secondo comma dell'articolo 14 per la notifica delle violazioni, quando essa non e' prevista dalle leggi vigenti. Le multe e le ammende inflitte con sentenze divenute irrevocabili o con decreti divenuti esecutivi alla data di entrata in vigore della presente legge sono riscosse, insieme con le spese del procedimento, con l'osservanza delle norme sull'esecuzione delle pene pecuniarie. Restano salve le pene accessorie e la confisca, nei casi in cui le stesse sono applicabili a norma dell'articolo 20. Restano salvi, altresi', i provvedimenti adottati in ordine alla patente di guida ed al documento di circolazione, ai sensi del testo unico delle norme sulla circolazione stradale, approvato con decreto del Presidente della Repubblica 15 giugno 1959, n. 393, e della legge 20 giugno 1935, n. 1349, sui servizi di trasporto merci. Per ogni altro effetto si applica il secondo comma dell'articolo 2 del codice penale.

### Art. 42. - (Disposizioni abrogate)

Sono abrogati la legge 3 maggio 1967, n. 317, gli articoli 4 e 5 della legge 9 ottobre 1967, n. 950, gli articoli 14 e 15 del decreto del Presidente della Repubblica 29 dicembre 1969, n. 1228, l'articolo 13 della legge 29 ottobre 1971, n. 889, la legge 24 dicembre 1975, n. 706, nonche' ogni altra disposizione incompatibile con la presente legge.

### Art. 43. - (Entrata in vigore)

Le norme di questo Capo entrano in vigore il centottantesimo giorno dalla data della pubblicazione della presente legge nella Gazzetta Ufficiale della Repubblica italiana.

## AGGRAVAMENTO DI PENE E NUOVE DISPOSIZIONI PENALI

### Art. 44. - (Pubblicazione di discussioni o deliberazioni segrete delle Camere)

L'articolo 683 del codice penale e' sostituito dal seguente: "Art. 683. - (Pubblicazione delle discussioni o delle deliberazioni segrete di una delle Camere). - Chiunque, senza autorizzazione, pubblica col mezzo della stampa, o con un altro dei mezzi indicati nell'articolo 662, anche per riassunto, il contenuto delle discussioni o delle deliberazioni segrete del Senato o della Camera dei deputati e' punito, qualora il fatto non costituisca un piu' grave reato, con l'arresto fino a trenta giorni o con l'ammenda da lire centomila a cinquecentomila".

### Art. 45. - (Pubblicazione arbitraria di atti di un procedimento penale)

L'articolo 684 del codice penale e sostituito dal seguente: "Art. 684. - (Pubblicazione arbitraria di atti di un procedimento penale). - Chiunque pubblica, in tutto o in parte, anche per riassunto o a guisa d'informazione, atti o documenti di un procedimento penale, di cui sia vietata per legge la pubblicazione, e' punito con l'arresto fino a trenta giorni o con l'ammenda da lire centomila a cinquecentomila".

### Art. 46. - (Indebita pubblicazione di notizie concernenti un procedimento penale)

L'articolo 685 del codice penale e' sostituito dal seguente: "Art. 685. - (Indebita pubblicazione di notizie concernenti un procedimento penale). - Chiunque pubblica i nomi dei giudici, con l'indicazione dei voti individuali che ad essi si attribuiscono nelle deliberazioni prese in un procedimento penale, e' punito con l'arresto fino a quindici giorni o con l'ammenda da lire cinquantamila a duecentomila".

### Art. 47. - Modifica all'articolo 697 del codice penale in materia di denuncia di armi all'autorit

Il secondo comma dell'articolo 697 del codice penale e' sostituito dal seguente: "Chiunque, avendo notizia che in un luogo da lui abitato si trovano armi o munizioni, omette di farne denuncia all'autorita', e' punito con l'arresto fino a due mesi o con l'ammenda fino a lire cinquecentomila".

### Art. 48. - (Omessa trasmissione dell'elenco dei protesti cambiari)

L'articolo 235 del regio-decreto 16 marzo 1942, n. 267, modificato per effetto della legge 24 dicembre 1975, n. 706, e' sostituito dal seguente: "Art. 235. - (Omessa trasmissione dell'elenco dei protesti cambiari). - Il pubblico ufficiale abilitato a levare protesti cambiari che, senza giustificato motivo, omette di inviare nel termine prescritto al presidente del tribunale gli elenchi dei protesti cambiari per mancato pagamento, o invia elenchi incompleti, e' punito con l'ammenda fino a lire cinquecentomila. La stessa pena si applica al procuratore del registro che nel termine prescritto non trasmette l'elenco delle dichiarazioni di rifiuto di pagamento a norma dell'articolo 13, secondo comma, o trasmette un elenco incompleto".

### Art. 49. - (Modifica dell'articolo 3 delle disposizioni relative al mercato mobiliare ed al trattamento fiscale dei titoli azionari)

L'ultimo comma dell'articolo 3 del decreto-legge 8 aprile 1974, n. 95, convertito con modificazioni nella legge 7 giugno 1974, n. 216, modificato per effetto della legge 24 dicembre 1975, n. 706, e' sostituito dal seguente: "Gli amministratori, i sindaci o revisori e i direttori generali di societa' o enti che non ottemperano alle richieste, non si uniformano alle prescrizioni della Commissione o comunque ostacolano l'esercizio delle sue funzioni sono puniti con l'arresto fino a tre mesi o con l'ammenda da lire 2 milioni a lire 40 milioni".

### Art. 50. - (Modifica dell'articolo 5 delle disposizioni relative al mercato mobiliare ed al trattamento fiscale dei titoli azionari)

Il sesto comma dell'articolo 5 del decreto-legge 8 aprile 1974, n. 95, convertito con modificazioni nella legge 7 giugno 1974, n. 216, modificato per effetto della legge 24 dicembre 1975, n. 706, e' sostituito dal seguente: "Gli amministratori delle societa' sono puniti con l'arresto fino a tre mesi o con l'ammenda da lire 2 milioni a lire 20 milioni ove omettano le comunicazioni previste dal presente articolo; ove le eseguano con un ritardo non superiore a trenta giorni sono puniti con l'ammenda da lire 1 milione a lire 20 milioni; ove eseguano comunicazioni false sono puniti con l'arresto fino a tre anni, salvo che il fatto non costituisca reato piu' grave. Per la violazione dell'obbligo di alienazione delle azioni o quote eccedenti si applicano le pene stabilite nel secondo comma dell'articolo 2630 del codice civile".

### Art. 51. - (Modifica dell'articolo 17 delle disposizioni relative al mercato mobiliare ed al trattamento fiscale dei titoli azionari)

L'ultimo comma dell'articolo 17 del decreto-legge 8 aprile 1974, n. 95, convertito con modificazioni nella legge 7 giugno 1974 n. 216, modificato per effetto della legge 24 dicembre 1975, n. 706, e' sostituito dal seguente: "I soggetti indicati nel primo comma che non eseguano le dichiarazioni e comunicazioni prescritte dal presente articolo nei termini ivi stabiliti sono puniti con l'arresto fino a tre mesi o con l'ammenda da lire 2 milioni a lire 40 milioni; ove le eseguano con un ritardo non superiore a trenta giorni sono puniti con l'ammenda da lire 1 milione a lire 20 milioni; ove eseguano dichiarazioni e comunicazioni false sono puniti con l'arresto fino a tre anni".

### Art. 52. - (Modifica dell'articolo 18 delle disposizioni relative al mercato mobiliare ed al trattamento fiscale dei titoli azionari)

L'ultimo comma dell'articolo 18 del decreto-legge 8 aprile 1974, n. 95, convertito con modificazioni nella legge 7 giugno 1974, n. 216, modificato per effetto della legge 24 dicembre 1975, n. 706, e' sostituito dal seguente: "L'omissione della comunicazione alla Commissione o la inosservanza delle prescrizioni da essa stabilite sono punite con l'ammenda da lire 4 milioni a lire 40 milioni".

### ((PENE SOSTITUTIVE DELLE PENE DETENTIVE BREVI)) SEZIONE I APPLICAZIONE DELLE SANZIONI SOSTITUTIVE

#### Art. 53. - (( (Sostituzione delle pene detentive brevi). ))

((Il giudice, nel pronunciare sentenza di condanna o di applicazione della pena su richiesta delle parti ai sensi dell'articolo 444 del codice di procedura penale, quando ritiene di dover determinare la durata della pena detentiva entro il limite di quattro anni, puo' sostituire tale pena con quella della semiliberta' o della detenzione domiciliare; quando ritiene di doverla determinare entro il limite di tre anni, puo' sostituirla anche con il lavoro di pubblica utilita'; quando ritiene di doverla determinare entro il limite di un anno, puo' sostituirla altresi' con la pena pecuniaria della specie corrispondente, determinata ai sensi dell'articolo 56-quater. Con il decreto penale di condanna, il giudice, su richiesta dell'indagato o del condannato, puo' sostituire la pena detentiva determinata entro il limite di un anno, oltre che con la pena pecuniaria, con il lavoro di pubblica utilita'. Si applicano le disposizioni dei commi 1-bis e 1- ter dell'articolo 459 del codice di procedura penale. Ai fini della determinazione dei limiti di pena detentiva entro i quali possono essere applicate pene sostitutive, si tiene conto della pena aumentata ai sensi dell'articolo 81 del codice penale.))

----------- AGGIORNAMENTO (16) La Corte Costituzionale con sentenza 15-29 giugno 1995, n.284 (in G.U. 1ª s.s. 5/7/1995, n.28) ha dichiarato "l'illegittimita' costituzionale dell'art. 53 della legge 24 novembre 1981, n. 689 (Modifiche al sistema penale), nella parte in cui non prevede l'applicabilita' delle sanzioni sostitutive delle pene detentive brevi ai reati militari, secondo i principi di cui in motivazione." ----------- AGGIORNAMENTO (46) La Corte Costituzionale, con sentenza 12 gennaio - 1 febbraio 2022, n. 28 (in G.U. 1ª s.s. 2/2/2022, n. 5), ha dichiarato "l'illegittimita' costituzionale dell'art. 53, secondo comma, della legge 24 novembre 1981 n. 689 (Modifiche al sistema penale), nella parte in cui prevede che «[i]l valore giornaliero non puo' essere inferiore alla somma indicata dall'art. 135 del codice penale e non puo' superare di dieci volte tale ammontare», anziche' «[i]l valore giornaliero non puo' essere inferiore a 75 euro e non puo' superare di dieci volte la somma indicata dall'art. 135 del codice penale»".

#### Art. 54.

((ARTICOLO ABROGATO DAL D.L. 14 GIUGNO 1993, N.187))

#### Art. 55. - (( (Semiliberta' sostitutiva). ))

((La semiliberta' sostitutiva comporta l'obbligo di trascorrere almeno otto ore al giorno in un istituto di pena e di svolgere, per la restante parte del giorno, attivita' di lavoro, di studio, di formazione professionale o comunque utili alla rieducazione ed al reinserimento sociale, secondo il programma di trattamento predisposto e approvato ai sensi dei commi seguenti. I condannati alla semiliberta' sostitutiva sono assegnati in appositi istituti o nelle apposite sezioni autonome di istituti ordinari, di cui al secondo comma dell'articolo 48 della legge 26 luglio 1975, n. 354, situati nel comune di residenza, di domicilio, di lavoro o di studio del condannato o in un comune vicino. Durante il periodo di permanenza negli istituti o nelle sezioni indicate nel primo periodo, il condannato e' sottoposto alle norme della legge 26 luglio 1975, n. 354, e del decreto del Presidente della Repubblica 30 giugno 2000, n. 230, in quanto compatibili. Nei casi di cui all'articolo 66, il direttore riferisce al magistrato di sorveglianza e all'ufficio di esecuzione penale esterna. Il semilibero e' sottoposto a un programma di trattamento predisposto dall'ufficio di esecuzione penale esterna ed approvato dal giudice, nel quale sono indicate le ore da trascorrere in istituto e le attivita' da svolgere all'esterno. L'ufficio di esecuzione penale esterna e' incaricato della vigilanza e dell'assistenza del condannato in liberta', secondo le modalita' previste dall'articolo 118 del decreto del Presidente della Repubblica 30 giugno 2000, n. 230. Si applicano, in quanto compatibili, le disposizioni previste dall'articolo 101, commi 1, 2 e da 5 a 9, del decreto del Presidente della Repubblica 30 giugno 2000, n. 230. Al condannato alla pena sostitutiva della semiliberta' non si applica l'articolo 120 del decreto legislativo 30 aprile 1992, n. 285.))

#### Art. 56. - (( (Detenzione domiciliare sostitutiva). ))

((La detenzione domiciliare sostitutiva comporta l'obbligo di rimanere nella propria abitazione o in altro luogo di privata dimora ovvero in luogo pubblico o privato di cura, assistenza o accoglienza ovvero in comunita' o in case famiglia protette, per non meno di dodici ore al giorno, avuto riguardo a comprovate esigenze familiari, di studio, di formazione professionale, di lavoro o di salute del condannato. In ogni caso, il condannato puo' lasciare il domicilio per almeno quattro ore al giorno, anche non continuative, per provvedere alle sue indispensabili esigenze di vita e di salute, secondo quanto stabilito dal giudice. Il giudice dispone la detenzione domiciliare sostitutiva tenendo conto anche del programma di trattamento elaborato dall'ufficio di esecuzione penale esterna, che prende in carico il condannato e che riferisce periodicamente sulla sua condotta e sul percorso di reinserimento sociale. Il luogo di esecuzione della pena deve assicurare le esigenze di tutela della persona offesa dal reato e non puo' essere un immobile occupato abusivamente. Se il condannato non ha la disponibilita' di un domicilio idoneo, l'ufficio di esecuzione penale esterna predispone il programma di trattamento, individuando soluzioni abitative anche comunitarie adeguate alla detenzione domiciliare. Il giudice, se lo ritiene necessario per prevenire il pericolo di commissione di altri reati o per tutelare la persona offesa, puo' prescrivere procedure di controllo mediante mezzi elettronici o altri strumenti tecnici, conformi alle caratteristiche funzionali e operative degli apparati di cui le Forze di polizia abbiano l'effettiva disponibilita'. La temporanea indisponibilita' di tali mezzi non puo' ritardare l'inizio della esecuzione della detenzione domiciliare. Si applicano, in quanto compatibili, le disposizioni di cui all'articolo 275-bis, commi 2 e 3, del codice di procedura penale. Si applica, in quanto compatibile, l'articolo 100 del decreto del Presidente della Repubblica 30 giugno 2000, n. 230. Al condannato alla pena sostitutiva della detenzione domiciliare non si applica l'articolo 120 del decreto legislativo 30 aprile 1992, n. 285.))

#### Art. 56-bis. - (( (Lavoro di pubblica utilita' sostitutivo). ))

((Il lavoro di pubblica utilita' consiste nella prestazione di attivita' non retribuita in favore della collettivita' da svolgere presso lo Stato, le Regioni, le Province, le Citta' metropolitane, i Comuni o presso enti o organizzazioni di assistenza sociale e di volontariato. L'attivita' viene svolta di regola nell'ambito della regione in cui risiede il condannato e comporta la prestazione di non meno di sei ore e non piu' di quindici ore di lavoro settimanale da svolgere con modalita' e tempi che non pregiudichino le esigenze di lavoro, di studio, di famiglia e di salute del condannato. Tuttavia, se il condannato lo richiede, il giudice puo' ammetterlo a svolgere il lavoro di pubblica utilita' per un tempo superiore. La durata giornaliera della prestazione non puo' comunque oltrepassare le otto ore. Ai fini del computo della pena, un giorno di lavoro di pubblica utilita' consiste nella prestazione di due ore di lavoro. Fermo quanto previsto dal presente articolo, le modalita' di svolgimento del lavoro di pubblica utilita' sono determinate con decreto del Ministro della giustizia, d'intesa con la Conferenza unificata di cui all'articolo 8 del decreto legislativo 28 agosto 1997, n. 281. In caso di decreto penale di condanna o di sentenza di applicazione della pena ai sensi dell'articolo 444 del codice di procedura penale, il positivo svolgimento del lavoro di pubblica utilita', se accompagnato dal risarcimento del danno o dalla eliminazione delle conseguenze dannose del reato, ove possibili, comporta la revoca della confisca eventualmente disposta, salvi i casi di confisca obbligatoria, anche per equivalente, del prezzo, del profitto o del prodotto del reato ovvero delle cose la cui fabbricazione, uso e porto, detenzione o alienazione costituiscano reato. Al condannato alla pena sostitutiva del lavoro di pubblica utilita' non si applica l'articolo 120 del decreto legislativo 30 aprile 1992, n. 285.))

#### Art. 56-ter. - (( (Prescrizioni comuni). ))

((La semiliberta', la detenzione domiciliare e il lavoro di pubblica utilita' comportano, in ogni caso, le seguenti prescrizioni: 1) il divieto di detenere e portare a qualsiasi titolo armi, munizioni ed esplosivi, anche se e' stata concessa la relativa autorizzazione di polizia; 2) il divieto di frequentare abitualmente, senza giustificato motivo, pregiudicati o persone sottoposte a misure di sicurezza, a misure di prevenzione o comunque persone che espongano concretamente il condannato al rischio di commissione di reati, salvo si tratti di familiari o di altre persone conviventi stabilmente; 3) l'obbligo di permanere nell'ambito territoriale, di regola regionale, stabilito nel provvedimento che applica o da' esecuzione alla pena sostitutiva; 4) il ritiro del passaporto e la sospensione della validita' ai fini dell'espatrio di ogni altro documento equipollente; 5) l'obbligo di conservare, di portare con se' e di presentare ad ogni richiesta degli organi di polizia il provvedimento che applica o da' esecuzione alla pena sostitutiva e l'eventuale provvedimento di modifica delle modalita' di esecuzione della pena, adottato a norma dell'articolo 64. Al fine di prevenire la commissione di ulteriori reati, il giudice puo' altresi' prescrivere il divieto di avvicinamento ai luoghi frequentati dalla persona offesa. Si applica l'articolo 282-ter del codice di procedura penale, in quanto compatibile.))

#### Art. 56-quater. - (( (Pena pecuniaria sostitutiva). ))

((Per determinare l'ammontare della pena pecuniaria sostitutiva il giudice individua il valore giornaliero al quale puo' essere assoggettato l'imputato e lo moltiplica per i giorni di pena detentiva. Il valore giornaliero non puo' essere inferiore a 5 euro e superiore a 2.500 euro e corrisponde alla quota di reddito giornaliero che puo' essere impiegata per il pagamento della pena pecuniaria, tenendo conto delle complessive condizioni economiche, patrimoniali e di vita dell'imputato e del suo nucleo familiare. Alla sostituzione della pena detentiva con la pena pecuniaria si applica l'articolo 133-ter del codice penale.))

#### Art. 57. - (( (Durata ed effetti delle pene sostitutive e criteri di ragguaglio). ))

((La durata della semiliberta' sostitutiva e della detenzione domiciliare sostitutiva e' pari a quella della pena detentiva sostituita. La durata del lavoro di pubblica utilita' corrisponde a quella della pena detentiva sostituita ed e' determinata sulla base dei criteri di cui all'articolo 56-bis. Per ogni effetto giuridico, la semiliberta' sostitutiva, la detenzione domiciliare sostitutiva e il lavoro di pubblica utilita' sostitutivo si considerano come pena detentiva della specie corrispondente a quella della pena sostituita ed un giorno di pena detentiva equivale a un giorno di semiliberta' sostitutiva, di detenzione domiciliare sostitutiva o di lavoro di pubblica utilita' sostitutivo. La pena pecuniaria si considera sempre come tale, anche se sostitutiva della pena detentiva.))

#### Art. 58. - (Potere discrezionale del giudice nell'applicazione e nella scelta delle pene sostitutive)

Il giudice, nei limiti fissati dalla legge e tenuto conto dei criteri indicati nell'articolo 133 del codice penale, se non ordina la sospensione condizionale della pena, puo' applicare le pene sostitutive della pena detentiva quando risultano piu' idonee alla rieducazione del condannato e quando, anche attraverso opportune prescrizioni, assicurano la prevenzione del pericolo di commissione di altri reati. La pena detentiva non puo' essere sostituita quando sussistono fondati motivi per ritenere che le prescrizioni non saranno adempiute dal condannato. Tra le pene sostitutive il giudice sceglie quella piu' idonea alla rieducazione e al reinserimento sociale del condannato con il minor sacrificio della liberta' personale, indicando i motivi che giustificano l'applicazione della pena sostitutiva e la scelta del tipo. ((Le pene sostitutive della semiliberta', della detenzione domiciliare e del lavoro di pubblica utilita' possono essere applicate solo con il consenso dell'imputato, espresso personalmente o a mezzo di procuratore speciale.)) Quando applica la semiliberta' o la detenzione domiciliare, il giudice deve indicare le specifiche ragioni per cui ritiene inidonei nel caso concreto il lavoro di pubblica utilita' o la pena pecuniaria. In ogni caso, nella scelta tra la semiliberta', la detenzione domiciliare o il lavoro di pubblica utilita', il giudice tiene conto delle condizioni legate all'eta', alla salute fisica o psichica, alla maternita', o alla paternita' nei casi di cui all'articolo 47-quinquies, comma 7, della legge 26 luglio 1975, n. 354, fermo quanto previsto dall'articolo 69, terzo e quarto comma. Il giudice tiene altresi' conto delle condizioni di disturbo da uso di sostanze stupefacenti, psicotrope o alcoliche ovvero da gioco d'azzardo, certificate dai servizi pubblici o privati autorizzati indicati all'articolo 94, comma 1, del decreto del Presidente della Repubblica 9 ottobre 1990, n. 309, nonche' delle condizioni di persona affetta da AIDS conclamata o da grave deficienza immunitaria, certificate dai servizi indicati dall'articolo 47-quater, comma 2, della legge 26 luglio 1975, n. 354.

#### Art. 59. - (( (Condizioni soggettive per la sostituzione della pena detentiva). ))

((La pena detentiva non puo' essere sostituita: a) nei confronti di chi ha commesso il reato per cui si procede entro tre anni dalla revoca della semiliberta', della detenzione domiciliare o del lavoro di pubblica utilita' ai sensi dell'articolo 66, ovvero nei confronti di chi ha commesso un delitto non colposo durante l'esecuzione delle medesime pene sostitutive; e' fatta comunque salva la possibilita' di applicare una pena sostitutiva di specie piu' grave di quella revocata; b) con la pena pecuniaria, nei confronti di chi, nei cinque anni precedenti, e' stato condannato a pena pecuniaria, anche sostitutiva, e non l'ha pagata, salvi i casi di conversione per insolvibilita' ai sensi degli articoli 71 e 103; c) nei confronti dell'imputato a cui deve essere applicata una misura di sicurezza personale, salvo i casi di parziale incapacita' di intendere e di volere; d) nei confronti dell'imputato di uno dei reati di cui all'articolo 4-bis della legge 26 luglio 1975, n. 354, salvo che sia stata riconosciuta la circostanza attenuante di cui all' articolo 323-bis, secondo comma, del codice penale. Le disposizioni del presente articolo non si applicano agli imputati minorenni.))

-------------- AGGIORNAMENTO (22) La Corte Costituzionale con sentenza 12-18 febbraio 1998, n.16 (in G.U. 1a s.s. 25/2/1998, n.8) ha dichiarato "l'illegittimita' costituzionale dell'art. 59 della legge 24 novembre 1981, n. 689 (Modifiche al sistema penale), nella parte in cui non esclude che le condizioni soggettive in esso prevedute per l'applicazione delle sanzioni sostitutive si estendano agli imputati minorenni."

#### Art. 60.

((ARTICOLO ABROGATO DALLA L. 12 GIUGNO 2003, N.134))

#### Art. 61. - (( (Condanna a pena sostitutiva). ))

((Nel dispositivo della sentenza di condanna, della sentenza di applicazione della pena e del decreto penale, il giudice indica la specie e la durata della pena detentiva sostituita e la specie, la durata ovvero l'ammontare della pena sostitutiva.))

#### Art. 61-bis. - (( (Esclusione della sospensione condizionale della pena). ))

((Le disposizioni di cui agli articoli 163 e seguenti del codice penale, relative alla sospensione condizionale della pena, non si applicano alle pene sostitutive previste dal presente Capo.))

#### Art. 62. - (( (Esecuzione della semiliberta' e della detenzione domiciliare sostitutive). ))

((Quando deve essere eseguita una sentenza di condanna a pena sostitutiva della semiliberta' o della detenzione domiciliare, il pubblico ministero trasmette la sentenza al magistrato di sorveglianza del luogo di domicilio del condannato. Il provvedimento di esecuzione e' notificato altresi' al difensore nominato per la fase dell'esecuzione o, in difetto, al difensore della fase del giudizio. Il magistrato di sorveglianza procede a norma dell'articolo 678, comma 1-bis, del codice di procedura penale e, previa verifica dell'attualita' delle prescrizioni, entro il quarantacinquesimo giorno dalla ricezione della sentenza provvede con ordinanza con cui conferma e, ove necessario, modifica le modalita' di esecuzione e le prescrizioni della pena. L'ordinanza e' immediatamente trasmessa per l'esecuzione all'ufficio di pubblica sicurezza del comune in cui il condannato e' domiciliato ovvero, in mancanza di questo, al comando dell'Arma dei carabinieri territorialmente competente. L'ordinanza e' trasmessa anche all'ufficio di esecuzione penale esterna e, nel caso di semiliberta', al direttore dell'istituto penitenziario cui il condannato e' stato assegnato. Appena ricevuta l'ordinanza prevista al secondo comma, l'organo di polizia ne consegna copia al condannato ingiungendogli di attenersi alle prescrizioni in essa contenute e di presentarsi immediatamente all'ufficio di esecuzione penale esterna. Provvede altresi' al ritiro e alla custodia delle armi, munizioni ed esplosivi e del passaporto ed alla apposizione sui documenti equipollenti dell'annotazione "documento non valido per l'espatrio", limitatamente alla durata della pena. Se il condannato e' detenuto o internato, l'ordinanza del magistrato di sorveglianza e' trasmessa anche al direttore dell'istituto penitenziario, il quale deve informare anticipatamente l'organo di polizia della dimissione del condannato. La pena sostitutiva inizia a decorrere dal giorno successivo a quello della dimissione. Cessata l'esecuzione della pena, le cose ritirate e custodite ai sensi del terzo comma sono restituite a cura dello stesso organo di polizia; vengono inoltre annullate le annotazioni effettuate ai sensi dello stesso terzo comma. Di tutti gli adempimenti espletati e' redatto processo verbale ed e' data notizia al questore e agli altri uffici interessati, nonche' al direttore dell'istituto presso cui si trova il condannato alla semiliberta'.))

#### Art. 63. - (( (Esecuzione del lavoro di pubblica utilita' sostitutivo). ))

((La sentenza penale irrevocabile o il decreto penale esecutivo che applicano il lavoro di pubblica utilita' sono immediatamente trasmessi per estratto a cura della cancelleria all'ufficio di pubblica sicurezza o, in mancanza di questo, al comando dell'Arma dei carabinieri competenti in relazione al comune in cui il condannato risiede, nonche' all'ufficio di esecuzione penale esterna che deve prendere in carico il condannato. La sentenza penale irrevocabile o il decreto penale esecutivo sono altresi' trasmessi al pubblico ministero per gli adempimenti di cui all'articolo 70. Appena ricevuto il provvedimento di cui al primo comma, l'organo di polizia ne consegna copia al condannato ingiungendogli di attenersi alle prescrizioni in esso contenute e di presentarsi immediatamente all'ufficio di esecuzione penale esterna. Qualora il condannato sia detenuto o internato, copia del provvedimento e' comunicata altresi' al direttore dell'istituto, il quale informa anticipatamente l'organo di polizia e l'ufficio di esecuzione penale esterna della dimissione del condannato. Immediatamente dopo la dimissione, il condannato si presenta all'ufficio di esecuzione penale esterna per l'esecuzione del lavoro di pubblica utilita'. Con la sentenza o con il decreto penale, il giudice incarica l'ufficio di esecuzione penale esterna e gli organi di polizia indicati al primo comma di verificare l'effettivo svolgimento del lavoro di pubblica utilita'. L'ufficio di esecuzione penale esterna riferisce periodicamente al giudice che ha applicato la pena sulla condotta del condannato e sul percorso di reinserimento sociale. Al termine del lavoro di pubblica utilita', l'ufficio di esecuzione penale esterna riferisce al giudice che, fuori dai casi previsti dall'articolo 66, dichiara eseguita la pena ed estinto ogni altro effetto penale, ad eccezione delle pene accessorie perpetue, e dispone la revoca della confisca nei casi di cui all'articolo 56-bis, quinto comma.))

#### Art. 64. - (( (Modifica delle modalita' di esecuzione delle pene sostitutive). ))

((Le prescrizioni imposte con l'ordinanza prevista dall'articolo 62, su istanza del condannato da inoltrare tramite l'ufficio di esecuzione penale esterna, possono essere modificate per comprovati motivi dal magistrato di sorveglianza, che procede nelle forme dell'articolo 678, comma 1-bis, del codice di procedura penale. Le prescrizioni imposte con la sentenza che applica il lavoro di pubblica utilita', su istanza del condannato da inoltrare tramite l'ufficio di esecuzione penale esterna, possono essere modificate per comprovati motivi dal giudice che ha applicato la pena sostitutiva, il quale provvede a norma dell'articolo 667, comma 4, del codice di procedura penale. I provvedimenti di cui al primo e al secondo comma sono immediatamente trasmessi all'ufficio di esecuzione penale esterna, all'organo di polizia o al direttore dell'istituto competenti per il controllo sull'adempimento delle prescrizioni. Non possono essere modificate le prescrizioni di cui all'articolo 56-ter, primo comma, numeri 1, 2, 4 e 5.))

#### Art. 65. - Controllo sull'adempimento delle prescrizioni

L'ufficio di pubblica sicurezza del luogo in cui il condannato sconta ((le pene sostitutive della semiliberta', della detenzione domiciliare o del lavoro di pubblica utilita' ovvero)), in mancanza di questo, il comando dell'Arma dei carabinieri territorialmente competente ((, e il nucleo di Polizia penitenziaria presso l'ufficio di esecuzione penale esterna verificano)) periodicamente che il condannato adempia alle prescrizioni impostegli e ((tengono)) un registro nominativo ed un fascicolo per ogni condannato sottoposto a controllo. Nel fascicolo individuale sono ((custodite la)) sentenza di condanna ((che applica il lavoro di pubblica utilita' sostitutivo ovvero)) l'ordinanza del magistrato di sorveglianza con le eventuali successive modifiche delle modalita' di esecuzione ((della semiliberta' sostitutiva o della detenzione domiciliare sostitutiva)), copia della corrispondenza con l'autorita' giudiziaria e con le altre autorita', una cartella biografica in cui sono riassunte le condanne riportate e ogni altro documento relativo all'esecuzione della pena. Si applicano al condannato alla ((semiliberta')) le norme di cui all'articolo 26 del decreto del Presidente della Repubblica ((30 giugno 2000, n. 230)). Il controllo sull'osservanza dell'obbligo prescritto dal primo comma dell'articolo 55 viene effettuato dal direttore dell'istituto ((...)). ((...))

#### Art. 66. - (( (Revoca per inosservanza delle prescrizioni). ))

((Salvo quanto previsto dall'articolo 71 per la pena pecuniaria, la mancata esecuzione della pena sostitutiva, ovvero la violazione grave o reiterata degli obblighi e delle prescrizioni ad essa inerenti, ne determina la revoca e la parte residua si converte nella pena detentiva sostituita ovvero in altra pena sostitutiva piu' grave. Gli ufficiali e gli agenti della polizia giudiziaria, il direttore dell'istituto a cui il condannato e' assegnato o il direttore dell'ufficio di esecuzione penale esterna informano, senza indugio, il giudice che ha applicato il lavoro di pubblica utilita', ovvero il magistrato di sorveglianza che ha emesso l'ordinanza prevista dall'articolo 62, di ogni violazione degli adempimenti sui quali gli organi medesimi esercitano i rispettivi controlli. Il magistrato di sorveglianza compie, ove occorra, sommari accertamenti e, qualora ritenga doversi disporre la revoca della semiliberta' o della detenzione domiciliare e la conversione previste dal primo comma, procede a norma dell'articolo 666 del codice di procedura penale. Allo stesso modo procede il giudice che ha applicato il lavoro di pubblica utilita'.))

#### Art. 67. - (( (Inapplicabilita' delle misure alternative alla detenzione). ))

((Salvo quanto previsto dall'articolo 47, comma 3-ter, della legge 26 luglio 1975, n. 354, le misure alternative alla detenzione di cui al capo VI del titolo I della medesima legge n. 354 del 1975, non si applicano al condannato in espiazione di pena sostitutiva. Salvo che si tratti di minori di eta' al momento della condanna, le misure di cui al primo comma non si applicano altresi', prima dell'avvenuta espiazione di meta' della pena residua, al condannato in espiazione di pena detentiva per conversione effettuata ai sensi dell'articolo 66 o del quarto comma dell'articolo 72.))

--------------- AGGIORNAMENTO (20) La Corte Costituzionale con sentenza 9-22 aprile 1997, n.109 (in G.U. 1a s.s. 30/4/1997, n.18) ha dichiarato "l'illegittimita' costituzionale dell'art. 67 della legge 24 novembre 1981, n. 689 (Modifiche al sistema penale), nella parte in cui si applica ai condannati minori di eta' al momento della condanna."

#### Art. 68. - (( (Sospensione dell'esecuzione delle pene sostitutive). ))

((L'esecuzione della semiliberta' sostitutiva, della detenzione domiciliare sostitutiva o del lavoro di pubblica utilita' sostitutivo e' sospesa in caso di notifica di un ordine di carcerazione o di consegna; l'esecuzione e' altresi' sospesa in caso di arresto o di fermo del condannato o di applicazione, anche provvisoria, di una misura di sicurezza detentiva. L'ordine di esecuzione della semiliberta' sostitutiva, della detenzione domiciliare sostitutiva o del lavoro di pubblica utilita' sostitutivo emesso nei confronti dell'imputato detenuto o internato non sospende l'esecuzione di pene detentive o l'esecuzione, anche provvisoria, di misure di sicurezza detentive, ne' il corso della custodia cautelare. Nei casi previsti dal primo comma, il giudice ovvero il magistrato di sorveglianza determinano la durata residua della pena sostitutiva e trasmettono il provvedimento al direttore dell'istituto in cui si trova il condannato; questi informa anticipatamente l'organo di polizia della data in cui riprendera' l'esecuzione della pena sostitutiva. La pena sostitutiva riprende a decorrere dal giorno successivo a quello della cessazione della esecuzione della pena detentiva ovvero dal secondo giorno successivo, in relazione alle necessita' di viaggio e alle condizioni dei trasporti.))

#### Art. 69. - (( (Licenze ai condannati alla semiliberta' e alla detenzione domiciliare. Sospensione e rinvio delle pene sostitutive). ))

((Per giustificati motivi, attinenti alla salute, al lavoro, allo studio, alla formazione, alla famiglia o alle relazioni affettive, al condannato alla pena sostitutiva della semiliberta' o della detenzione domiciliare possono essere concesse licenze per la durata necessaria e comunque non superiore nel complesso a quarantacinque giorni all'anno. Si applica il terzo comma dell'articolo 52 della legge 26 luglio 1975, n. 354. Al condannato che, allo scadere della licenza o dopo la revoca di essa, non rientra in istituto o nel luogo indicato nell'articolo 56, primo comma, e' applicabile l'articolo 66, primo comma. Per gli stessi giustificati motivi di cui al primo comma ovvero per cause riconducibili all'attivita' dei soggetti di cui all'articolo 56-bis, la pena sostitutiva del lavoro di pubblica utilita' puo' essere sospesa per un periodo non superiore nel complesso a quarantacinque giorni all'anno. Al condannato che, allo scadere della sospensione, non si presenta al lavoro e' applicabile l'articolo 66 secondo comma. Per il rinvio dell'esecuzione della pena sostitutiva della semiliberta' o della detenzione domiciliare nei casi di cui agli articoli 146 e 147 del codice penale si applica l'articolo 684 del codice di procedura penale. Al condannato alla semiliberta' puo' essere applicata la pena sostitutiva della detenzione domiciliare, ove compatibile. In tal caso, l'esecuzione della pena prosegue durante la detenzione domiciliare. Quando le condizioni di cui agli articoli 146 e 147 del codice penale non sono compatibili con la prosecuzione della prestazione lavorativa, il giudice che ha applicato il lavoro di pubblica utilita', nelle forme previste di cui all'articolo 666 del codice di procedura penale, dispone il rinvio dell'esecuzione della pena. Nelle medesime forme di cui al terzo e al quarto comma si provvede quando occorre disporre la proroga del termine del rinvio dell'esecuzione.))

#### Art. 70. - (( (Esecuzione di pene sostitutive concorrenti). ))

((Quando contro la stessa persona sono state pronunciate, per piu' reati, una o piu' sentenze o decreti penali di condanna a pena sostitutiva, si osservano, in quanto compatibili, le disposizioni degli articoli da 71 a 80 del codice penale. Se piu' reati importano pene sostitutive, anche di specie diversa, e il cumulo delle pene detentive sostituite non eccede complessivamente la durata di quattro anni, si applicano le singole pene sostitutive distintamente, anche oltre i limiti di cui all'articolo 53 per la pena pecuniaria e per il lavoro di pubblica utilita'. Se il cumulo delle pene detentive sostituite eccede complessivamente la durata di quattro anni, si applica per intero la pena sostituita, salvo che la pena residua da eseguire sia pari o inferiore ad anni quattro. Le pene sostitutive sono sempre eseguite dopo le pene detentive e, nell'ordine, si eseguono la semiliberta', la detenzione domiciliare ed il lavoro di pubblica utilita'. Per l'esecuzione delle pene sostitutive concorrenti si applica, in quanto compatibile, l'articolo 663 del codice di procedura penale. E' tuttavia fatta salva, limitatamente all'esecuzione del lavoro di pubblica utilita', anche concorrente con pene sostitutive di specie diversa, la competenza del giudice che ha applicato tale pena.))

#### Art. 71. - (( (Esecuzione della pena pecuniaria sostitutiva. Revoca e conversione per mancato pagamento). ))

((Alla pena pecuniaria sostitutiva della pena detentiva si applicano le disposizioni dell'articolo 660 del codice di procedura penale. Il mancato pagamento della pena pecuniaria sostitutiva, entro il termine di cui all'articolo 660 del codice di procedura penale indicato nell'ordine di esecuzione, ne comporta la revoca e la conversione nella semiliberta' sostitutiva o nella detenzione domiciliare sostitutiva. Si applica l'articolo 58. Se e' stato disposto il pagamento rateale, il mancato pagamento di una rata, alla scadenza stabilita, comporta la revoca della pena pecuniaria sostitutiva e la conversione ha luogo per la parte residua. Quando le condizioni economiche e patrimoniali del condannato al momento dell'esecuzione rendono impossibile il pagamento entro il termine indicato nell'ordine di esecuzione, la pena pecuniaria sostitutiva e' revocata e convertita nel lavoro di pubblica utilita' sostitutivo o, se il condannato si oppone, nella detenzione domiciliare sostitutiva. Si applicano le disposizioni del terzo periodo del secondo comma.))

#### Art. 72. - (Ipotesi di responsabilita' penale e revoca)

Il condannato alla pena sostitutiva della semiliberta' o della detenzione domiciliare che per piu' di dodici ore, senza giustificato motivo, rimane assente dall'istituto di pena ovvero si allontana da uno dei luoghi indicati nell'articolo 56 e' punito ai sensi del primo comma dell'articolo 385 del codice penale. Si applica la disposizione del quarto comma dell'articolo 385 del codice penale. Il condannato alla pena sostitutiva del lavoro di pubblica utilita' che, senza giustificato motivo, non si reca nel luogo in cui deve svolgere il lavoro ovvero lo abbandona e' punito ai sensi dell'articolo 56 del decreto legislativo 28 agosto 2000, n. 274. La condanna a uno dei delitti di cui ai commi primo e secondo importa la revoca della pena sostitutiva, salvo che il fatto sia di lieve entita'. La condanna a pena detentiva per un delitto non colposo commesso ((dopo l'applicazione ovvero)) durante l'esecuzione di una pena sostitutiva, diversa dalla pena pecuniaria, ne determina la revoca e la conversione per la parte residua nella pena detentiva sostituita, quando la condotta tenuta appare incompatibile con la prosecuzione della pena sostitutiva, tenuto conto dei criteri di cui all'articolo 58. La cancelleria del giudice che ha pronunciato la sentenza di cui al quarto comma informa senza indugio il magistrato di sorveglianza competente per la detenzione domiciliare sostitutiva o per la semiliberta' sostitutiva, ovvero il giudice che ha applicato il lavoro di pubblica utilita' sostitutivo.

#### Art. 73.

((ARTICOLO ABROGATO DAL D.P.R. 14 NOVEMBRE 2002, N.313))

#### Art. 74. - (Iscrizione nel casellario giudiziale)

Dopo l'articolo 58 della legge 26 luglio 1975, n. 354, e' inserito il seguente: "Art. 58-bis. - (Iscrizione nel casellario giudiziale). - Nel casellario giudiziale sono iscritti i provvedimenti della sezione di sorveglianza relativi alla irrogazione e alla revoca delle misure alternative alla pena detentiva".

#### Art. 75. - (( (Disposizioni relative ai minorenni). ))

((Le disposizioni del presente Capo si applicano anche, in quanto compatibili, agli imputati minorenni. Si applica l'articolo 30 del decreto del Presidente della Repubblica 22 settembre 1988, n. 448.))

#### Art. 75-bis. - (( (Disposizioni relative ai reati militari). ))

((Le disposizioni del presente Capo si applicano, in quanto compatibili, ai reati militari quando le prescrizioni risultano in concreto compatibili con la posizione soggettiva del condannato.))

#### Art. 76. - (( (Norme applicabili). ))

((Alle pene sostitutive previste dal presente Capo si applicano, in quanto compatibili, gli articoli 47, comma 12-bis, 51-bis, 51-quater e 53-bis della legge 26 luglio 1975, n. 354.))

## APPLICAZIONE DI SANZIONI SOSTITUTIVE SU RICHIESTA DELL'IMPUTATO

### Art. 77. - (Ambito e modalita' d'applicazione)

Nel corso dell'istruzione e fino a quando non sono compiute per la prima volta le formalita' di apertura del dibattimento, il giudice, quando ritiene, in seguito all'esame degli atti e agli accertamenti eventualmente disposti, che sussistono elementi per applicare per il reato per cui procede la sanzione sostitutiva della liberta' controllata o della pena pecuniaria puo' disporre con sentenza, su richiesta dell'imputato e con il parere favorevole del pubblico ministero, l'applicazione della sanzione sostitutiva, con esclusione di ogni pena accessoria e misura di sicurezza, ad eccezione della confisca nei casi previsti dal secondo comma dell'articolo 240 del codice penale. In tal caso, con la stessa sentenza, dichiara estinto il reato per intervenuta applicazione della sanzione sostitutiva su richiesta dell'imputato. Nella determinazione e nell'applicazione della sanzione sostitutiva si osservano le disposizioni della Sezione I di questo Capo. La sentenza produce i soli effetti espressamente previsti nella presente Sezione. Contro la sentenza e' ammesso soltanto ricorso per cassazione.((5))

------------- AGGIORNAMENTO (5) Il D.Lgs. 28 luglio 1989, n. 271 ha disposto (con l'art. 234 comma 1) che:" Salvo quanto stabilito dall'articolo 248 comma 4, sono abrogati gli articoli 77, 78, 79 e 80 della legge 24 novembre 1981 n. 689." Ha inoltre disposto con l'art.248 comma 4 che:" Continuano ad osservarsi le disposizioni relative alla applicazione di sanzioni sostitutive su richiesta dell'imputato, a norma della legge 24 novembre 1981 n. 689, se la richiesta medesima e' stata formulata anteriormente all'entrata in vigore del codice e sempre che l'interessato non si avvalga delle facolta' previste dall'articolo 247 e dal presente articolo."

### Art. 78. - (Competenza)

Sulla richiesta formulata dall'imputato prima dell'emissione del decreto di citazione a giudizio, della richiesta di citazione a giudizio o dell'ordinanza di rinvio a giudizio, provvede il pretore per i procedimenti dinanzi a lui pendenti ed il giudice istruttore negli altri casi; il parere del pubblico ministero e' espresso dal procuratore della Repubblica. Se la richiesta e' formulata in un momento successivo, provvede il giudice del dibattimento ed il parere e' espresso dal pubblico ministero di udienza.((5))

------------- AGGIORNAMENTO (5) Il D.Lgs. 28 luglio 1989, n. 271 ha disposto (con l'art. 234 comma 1) che:" Salvo quanto stabilito dall'articolo 248 comma 4, sono abrogati gli articoli 77, 78, 79 e 80 della legge 24 novembre 1981 n. 689." Ha inoltre disposto con l'art.248 comma 4 che:" Continuano ad osservarsi le disposizioni relative alla applicazione di sanzioni sostitutive su richiesta dell'imputato, a norma della legge 24 novembre 1981 n. 689, se la richiesta medesima e' stata formulata anteriormente all'entrata in vigore del codice e sempre che l'interessato non si avvalga delle facolta' previste dall'articolo 247 e dal presente articolo."

### Art. 79. - (Applicazione nell'ulteriore corso del procedimento)

Il giudice puo' procedere ai sensi dell'articolo 77 in ogni stato e grado del procedimento, quando l'imputato ha formulato la richiesta di cui allo stesso articolo nel termine ivi previsto.((5))

------------- AGGIORNAMENTO (5) Il D.Lgs. 28 luglio 1989, n. 271 ha disposto (con l'art. 234 comma 1) che:" Salvo quanto stabilito dall'articolo 248 comma 4, sono abrogati gli articoli 77, 78, 79 e 80 della legge 24 novembre 1981 n. 689." Ha inoltre disposto con l'art.248 comma 4 che:" Continuano ad osservarsi le disposizioni relative alla applicazione di sanzioni sostitutive su richiesta dell'imputato, a norma della legge 24 novembre 1981 n. 689, se la richiesta medesima e' stata formulata anteriormente all'entrata in vigore del codice e sempre che l'interessato non si avvalga delle facolta' previste dall'articolo 247 e dal presente articolo."

### Art. 80. - (Esclusioni soggettive)

Il provvedimento di cui all'articolo 77 non puo' essere emesso nei confronti di chi in precedenza ne ha gia' beneficiato o nei confronti di chi ha riportato condanna a pena detentiva.(2)((5))

----------- AGGIORNAMENTO (2) La Corte Costituzionale (in G.U. 1a s.s. 22/7/1987, n.30)con sentenza 3-6 luglio 1987, n.267 ha dichirato:" l'illegittimita' costituzionale dell'art. 80 della legge 24 novembre 1981, n. 689 (Modifiche al sistema penale), nella parte in cui esclude la reiterabilita' del provvedimento previsto dall'art. 77 della stessa legge quando l'imputato debba rispondere di reati che si legano con il vincolo della continuazione a quelli per i quali egli gia' ha beneficiato del provvedimento." ------------- AGGIORNAMENTO (5) Il D.Lgs. 28 luglio 1989, n. 271 ha disposto (con l'art. 234 comma 1) che:" Salvo quanto stabilito dall'articolo 248 comma 4, sono abrogati gli articoli 77, 78, 79 e 80 della legge 24 novembre 1981 n. 689." Ha inoltre disposto con l'art.248 comma 4 che:" Continuano ad osservarsi le disposizioni relative alla applicazione di sanzioni sostitutive su richiesta dell'imputato, a norma della legge 24 novembre 1981 n. 689, se la richiesta medesima e' stata formulata anteriormente all'entrata in vigore del codice e sempre che l'interessato non si avvalga delle facolta' previste dall'articolo 247 e dal presente articolo."

### Art. 81.

((ARTICOLO ABROGATO DAL D.P.R. 14 NOVEMBRE 2002, N.313))

### Art. 82. - (Esecuzione delle sanzioni sostitutive)

Per l'esecuzione delle sanzioni sostitutive si applicano le disposizioni della Sezione I di questo Capo.

### Art. 83. - (Violazione degli obblighi)

Colui il quale viola, in tutto o in parte, gli obblighi impostigli con la sentenza pronunciata a norma dell'articolo 77 e' punito con la reclusione da sei mesi a tre anni. In caso di condanna la pena non puo' essere sostituita a norma di questo Capo.

### Art. 84. - (Comunicazione all'imputato)

Quando per il reato per il quale si procede e' ammessa l'oblazione o puo' trovare applicazione la disposizione prevista dallo articolo 77 ne va fatta menzione nella comunicazione giudiziaria.

### Art. 85. - (Entrata in vigore)

Le disposizioni contenute nella presente Sezione si applicano anche ai reati commessi prima dell'entrata in vigore della presente legge.

## ESTENSIONE DELLA PERSEGUIBILITA' A QUERELA

### Art. 86. - (Nuovo testo degli articoli 334 e 335 del codice penale)

Gli articoli 334 e 335 del codice penale sono sostituiti dai seguenti: "Art. 334. - (Sottrazione o danneggiamento di cose sottoposte a sequestro disposto nel corso di un procedimento penale o dalla autorita' amministrativa). - Chiunque sottrae, sopprime, distrugge, disperde o deteriora una cosa sottoposta a sequestro disposto nel corso di un procedimento penale o dall'autorita' amministrativa e affidata alla sua custodia, al solo scopo di favorire il proprietario di essa, e' punito con la reclusione da sei mesi a tre anni e con la multa da lire centomila a un milione. Si applicano la reclusione da tre mesi a due anni e la multa da lire sessantamila a lire seicentomila se la sottrazione, la soppressione, la distruzione, la dispersione o il deterioramento sono commessi dal proprietario della cosa, affidata alla sua custodia. La pena e' della reclusione da un mese ad un anno e della multa fino a lire seicentomila, se il fatto e' commesso dal proprietario della cosa medesima non affidata alla sua custodia". "Art. 335. - (Violazione colposa di doveri inerenti alla custodia di cose sottoposte a sequestro disposto nel corso di un procedimento penale o dall'autorita' amministrativa). - Chiunque, avendo in custodia una cosa sottoposta a sequestro disposto nel corso di un procedimento penale o dall'autorita' amministrativa, per colpa ne cagiona la distruzione o la dispersione, ovvero ne agevola la sottrazione o la soppressione, e' punito con la reclusione fino a sei mesi o con la multa fino a lire seicentomila".

### Art. 87. - (Sottrazione, distruzione o danneggiamento di cose sottoposte a pignoramento, sequestro giudiziario o conservativo)

Il terzo comma dell'articolo 388 del codice penale e' sostituito dai seguenti commi: "Chiunque sottrae, sopprime, distrugge, disperde o deteriora una cosa di sua proprieta' sottoposta a pignoramento ovvero a sequestro giudiziario o conservativo e' punito con la reclusione fino a un anno e con la multa fino a lire seicentomila. Si applicano la reclusione da due mesi a due anni e la multa da lire sessantamila a lire seicentomila se il fatto e' commesso dal proprietario su una cosa affidata alla sua custodia e la reclusione da quattro mesi a tre anni e la multa da lire centomila a un milione se il fatto e' commesso dal custode al solo scopo di favorire il proprietario della cosa. Il custode di una cosa sottoposta a pignoramento ovvero a sequestro giudiziario o conservativo che indebitamente rifiuta, omette o ritarda un atto dell'ufficio e' punito con la reclusione fino ad un anno o con la multa fino a un milione. Il colpevole e' punito a querela della persona offesa".

### Art. 88. - (Violazione colposa dei doveri inerenti alla custodia di cose sottoposte a pignoramento o sequestro giudiziario o conservativo)

Dopo l'articolo 388 del codice penale e' inserito il seguente: "Art. 388-bis. - (Violazione colposa dei doveri inerenti alla custodia di cose sottoposte a pignoramento ovvero a sequestro giudiziario o conservativo). - Chiunque, avendo in custodia una cosa sottoposta a pignoramento ovvero a sequestro giudiziario o conservativo, per colpa ne cagiona la distruzione o la dispersione, ovvero ne agevola la soppressione o la sottrazione, e' punito, a querela della persona offesa, con la reclusione fino a sei mesi o con la multa fino a lire seicentomila".

### Art. 89. - (Casi di perseguibilita' a querela)

Dopo l'articolo 493 del codice penale e' inserito il seguente: "Art. 493-bis. - (Casi di perseguibilita' a querela). - I delitti previsti dagli articoli 485 e 486 e quelli previsti dagli articoli 488, 489 e 490, quando concernono una scrittura privata, sono punibili a querela della persona offesa. Si procede d'ufficio, se i fatti previsti dagli articoli di cui al precedente comma riguardano un testamento olografo".

### Art. 90. - (Modifica dell'articolo 570 del codice penale in materia di violazione degli obblighi di assistenza familiare)

Nell'articolo 570 del codice penale dopo il secondo comma e' inserito il seguente: "Il delitto e' punibile a querela della persona offesa salvo nei casi previsti dal numero 1 e, quando il reato e' commesso nei confronti dei minori, dal numero 2 del precedente comma".

### Art. 91. - (Modifica dell'articolo 582 del codice penale in materia di lesione personale)

Il secondo comma dell'articolo 582 del codice penale e' sostituito dal seguente: "Se la malattia ha una durata non superiore ai venti giorni e non concorre alcuna delle circostanze aggravanti previste negli articoli 583 e 585, ad eccezione di quelle indicate nel numero 1 e nell'ultima parte dell'articolo 577, il delitto e' punibile a querela della persona offesa".

### Art. 92. - (Modifica dell'articolo 590 del codice penale in materia di lesioni personali colpose)

L'ultimo comma dell'articolo 590 del codice penale e' sostituito dal seguente: "Il delitto e' punibile a querela della persona offesa, salvo nei casi previsti nel primo e secondo capoverso, limitatamente ai fatti commessi con violazione delle norme per la prevenzione degli infortuni sul lavoro o relative all'igiene del lavoro o che abbiano determinato una malattia professionale".

### Art. 93. - (Modifica dell'articolo 627 del codice penale in materia di sottrazione di cose comuni)

Il primo comma dell'articolo 627 del codice penale e' sostituito dal seguente: "Il comproprietario, socio o coerede che, per procurare a se' o ad altri un profitto, si impossessa della cosa comune, sottraendola a chi la detiene, e' punito, a querela della persona offesa, con la reclusione fino a due anni o con la multa da lire quarantamila a quattrocentomila".

### Art. 94. - (Usurpazione)

L'articolo 631 del codice penale e' sostituito dal seguente: "Art. 631. - (Usurpazione). - Chiunque, per appropriarsi, in tutto o in parte, dell'altrui cosa immobile, ne rimuove o altera i termini e' punito, a querela della persona offesa, con la reclusione fino a tre anni e con la multa fino a lire quattrocentomila".

### Art. 95. - (Deviazione di acque e modificazione dello stato dei luoghi)

L'articolo 632 del codice penale e' sostituito dal seguente: "Art. 632. - (Deviazione di acque e modificazione dello stato dei luoghi). - Chiunque, per procurare a se' o ad altri un ingiusto profitto, devia acque, ovvero immuta nell'altrui proprieta' lo stato dei luoghi, e' punito, a querela della persona offesa, con la reclusione fino a tre anni e con la multa fino a lire quattrocentomila".

### Art. 96. - (Modifica dell'articolo 636 del codice penale in materia di introduzione o abbandono di animali nel fondo altrui e pascolo abusivo)

Nell'articolo 636 del codice penale e' aggiunto in fine il seguente comma: "Il delitto e' punibile a querela della persona offesa".

### Art. 97. - (Casi di esclusione della perseguibilita' a querela)

Dopo l'articolo 639 del codice penale e' inserito il seguente: "Art. 639-bis. - (Casi di esclusione della perseguibilita' a querela). - Nei casi previsti dagli articoli 631, 632, 633 e 636 si procede d'ufficio se si tratta di acque, terreni, fondi o edifici pubblici o destinati ad uso pubblico".

### Art. 98. - (Modifica dell'articolo 640 del codice penale in materia di truffa)

Nell'articolo 640 del codice penale e' aggiunto in fine il seguente comma: "Il delitto e' punibile a querela della persona offesa, salvo che ricorra taluna delle circostanze previste dal capoverso precedente o un'altra circostanza aggravante".

### Art. 99. - (Norma transitoria)

Per i reati perseguibili a querela ai sensi delle disposizioni precedenti, connessi prima del giorno dell'entrata in vigore della presente legge, il termine per presentare la querela decorre dal giorno suddetto, se la persona offesa ha avuto in precedenza notizie del fatto costituente reato. Se e' pendente il procedimento, il giudice informa la persona offesa dal reato della facolta' di esercitare il diritto di querela e il termine decorre dal giorno in cui la persona offesa e' stata informata.

## DISPOSIZIONI IN MATERIA DI PENE PECUNIARIE

### Art. 100. - (Condizioni economiche del reo; valutazione agli effetti della pena pecuniaria - Pagamento rateale della multa o della ammenda)

Dopo l'articolo 133 del codice penale sono inseriti i seguenti: "Art. 133-bis. - (Condizioni economiche del reo; valutazione agli effetti della pena pecuniaria). - Nella determinazione dell'ammontare della multa o dell'ammenda il giudice deve tenere conto, oltre che dei criteri indicati dall'articolo precedente, anche delle condizioni economiche del reo. Il giudice puo' aumentare la multa o l'ammenda stabilite dalla legge sino al triplo o diminuirle sino ad un terzo quando, per le condizioni economiche del reo, ritenga che la misura massima sia inefficace ovvero che la misura minima sia eccessivamente gravosa". "Art. 133-ter. - (Pagamento rateale della multa o dell'ammenda). - Il giudice, con la sentenza di condanna o con il decreto penale, puo' disporre, in relazione alle condizioni economiche del condannato, che la multa o l'ammenda venga pagata in rate mensili da tre a trenta. Ciascuna rata tuttavia non puo' essere inferiore a lire trentamila". In ogni momento il condannato puo' estinguere la pena mediante un unico pagamento".

### Art. 101. - (Nuovo testo degli articoli 24, 26, 66, 78, 135 e 136 del codice penale)

Gli articoli 24, 26, 66, 78, 135, 136 del codice penale sono sostituiti dai seguenti: "Art. 24. - (Multa). - La pena della multa consiste nel pagamento allo Stato di una somma non inferiore a lire diecimila, ne' superiore a dieci milioni. Per i delitti determinati da motivi di lucro, se la legge stabilisce soltanto la pena della reclusione, il giudice puo' aggiungere la multa da lire diecimila a lire quattro milioni". "Art. 26. - (Ammenda). - La pena dell'ammenda consiste nel pagamento allo Stato di una somma non inferiore a lire quattromila ne' superiore a lire due milioni". "Art. 66. - (Limiti degli aumenti di pena nel caso di concorso di piu' circostanze aggravanti). - Se concorrono piu' circostanze aggravanti, la pena da applicare per effetto degli aumenti non puo' superare il triplo del massimo stabilito dalla legge per il reato, salvo che si tratti delle circostanze indicate nel secondo capoverso dell'articolo 63, ne' comunque eccedere: 1) gli anni trenta, se si tratta della reclusione; 2) gli anni cinque, se si tratta dell'arresto; 3) e, rispettivamente, lire venti milioni o quattro milioni, se si tratta della multa o dell'ammenda; ovvero, rispettivamente, lire sessanta milioni o dodici milioni se il giudice si avvale della facolta' di aumento indicata nel capoverso dell'articolo 133-bis". "Art. 78. - (Limiti degli aumenti delle pene principali). - Nel caso di concorso di reati preveduto dall'articolo 73, la pena da applicare a norma dello stesso articolo non puo' essere superiore al quintuplo della piu' grave fra le pene concorrenti, ne' comunque eccedere: 1) trenta anni per la reclusione; 2) sei anni per l'arresto; 3) lire trenta milioni per la multa e sei milioni per l'ammenda; ovvero lire centoventicinque milioni per la multa e venticinque milioni per l'ammenda, se il giudice si vale della facolta' di aumento indicata nel capoverso dell'articolo 133-bis. Nel caso di concorso di reati preveduto dall'articolo 74, la durata delle pene da applicare a norma dell'articolo stesso non puo' superare gli anni trenta. La parte della pena eccedente tale limite e' detratta in ogni caso dall'arresto". "Art. 135. - (Ragguaglio fra pene pecuniarie e pene detentive). - Quando, per qualsiasi effetto giuridico, si deve eseguire un ragguaglio fra pene pecuniarie e pene detentive, il computo ha luogo calcolando venticinquemila lire, o frazione di venticinquemila lire, di pena pecuniaria per un giorno di pena detentiva". "Art. 136. - (Modalita' di conversione di pene pecuniarie). - Le pene della multa e dell'ammenda, non eseguite per insolvibilita' del condannato, si convertono a norma di legge".

### Art. 102. - (( (Conversione delle pene pecuniarie principali per mancato pagamento). ))

((Il mancato pagamento della multa o dell'ammenda entro il termine di cui all'articolo 660 del codice di procedura penale indicato nell'ordine di esecuzione ne comporta la conversione nella semiliberta' sostitutiva. Il ragguaglio si esegue a norma dell'articolo 135 del codice penale. In ogni caso la semiliberta' sostitutiva non puo' avere durata superiore a quattro anni, se la pena convertita e' quella della multa, e durata superiore a due anni, se la pena convertita e' quella dell'ammenda. Se e' stato disposto il pagamento rateale, ai sensi dell'articolo 133-ter del codice penale, la conversione ha luogo per la parte residua della pena pecuniaria. Il condannato puo' sempre far cessare l'esecuzione della semiliberta' pagando la multa o l'ammenda, dedotta la somma corrispondente alla durata della pena da conversione espiata; a tal fine, puo' essere ammesso al pagamento rateale, ai sensi dell'articolo 133-ter del codice penale.))

------------- AGGIORNAMENTO (15) La Corte Costituzionale con sentenza 12-23 dicembre 1994, n.440 (in G.U. 1a s.s. 28/12/1994, n.53) ha dichiarato "l'illegittimita' costituzionale dell'art. 102, terzo comma, della legge 24 novembre 1981, n. 689 (Modifiche al sistema penale), nella parte in cui stabilisce che, agli effetti della conversione delle pene pecuniarie non eseguite per insolvibilita' del condannato, il ragguaglio ha luogo calcolando venticinquemila lire, o frazione di venticinquemila lire, anziche' settantacinquemila lire, o frazione di settantacinquemila lire, di pena pecuniaria per un giorno di liberta' controllata". ------------ AGGIORNAMENTO (18) La Corte Costituzionale con sentenza 14-21 giugno 1996, n.206 (in G.U. 1a s.s. 26/6/1996, n.26) ha dichiarato "l'illegittimita' costituzionale dell'art. 102, secondo comma, della legge 24 novembre 1981, n. 689 (Modifiche al sistema penale) nella parte in cui non consente che il lavoro sostitutivo, a richiesta del condannato, sia concesso anche nel caso in cui la pena pecuniaria da convertire sia superiore ad un milione". ------------- AGGIORNAMENTO (43) La Corte Costituzionale, con sentenza 9 - 12 gennaio 2012, n. 1 (in G.U. 1a s.s. 18/1/2012, n. 3) ha dichiarato "l'illegittimita' costituzionale, sopravvenuta dall'8 agosto 2009, dell'art. 102, terzo comma, della legge 24 novembre 1981, n. 689 (Modifiche al sistema penale), nella parte in cui stabilisce che, agli effetti della conversione delle pene pecuniarie non eseguite per insolvibilita' del condannato, il ragguaglio ha luogo calcolando euro 38, o frazione di euro 38, anziche' euro 250, o frazione di euro 250, di pena pecuniaria per un giorno di liberta' controllata".

### Art. 103. - (( (Mancato pagamento della pena pecuniaria per insolvibilita' del condannato). ))

((Quando le condizioni economiche e patrimoniali del condannato al momento dell'esecuzione rendono impossibile il pagamento della multa o dell'ammenda entro il termine di cui all'articolo 660 del codice di procedura penale indicato nell'ordine di esecuzione, la pena pecuniaria e' convertita nel lavoro di pubblica utilita' sostitutivo ovvero, se il condannato si oppone, nella detenzione domiciliare sostitutiva. Il ragguaglio si esegue in ogni caso a norma dell'articolo 135 del codice penale e un giorno di lavoro di pubblica utilita' sostitutivo consiste nella prestazione di due ore di lavoro. In ogni caso il lavoro di pubblica utilita' sostitutivo e la detenzione domiciliare sostitutiva non possono avere durata superiore a due anni, se la pena convertita e' la multa, e durata superiore a un anno, se la pena convertita e' l'ammenda. Se e' stato disposto il pagamento rateale, ai sensi dell'articolo 133-ter del codice penale, la conversione ha luogo per la parte residua della pena pecuniaria. Il condannato puo' in ogni caso far cessare l'esecuzione del lavoro di pubblica utilita' sostitutiva o della detenzione domiciliare sostitutiva pagando la multa o l'ammenda, dedotta la somma corrispondente alla durata della pena da conversione espiata. A tal fine puo' essere ammesso al pagamento rateale, ai sensi dell'articolo 133-ter del codice penale.))

### Art. 103-bis. - (( (Inapplicabilita' delle misure alternative alla detenzione). ))

((Le misure alternative alla detenzione, di cui al Capo VI del Titolo I della legge 26 luglio 1975 n. 354, non si applicano al condannato alla semiliberta' sostitutiva o alla detenzione domiciliare sostitutiva derivanti da conversione della pena pecuniaria ai sensi del presente Capo.))

### Art. 103-ter. - (( (Disposizioni applicabili). ))

((Alla semiliberta' sostitutiva, alla detenzione domiciliare sostitutiva e al lavoro di pubblica utilita' sostitutivo, quali pene da conversione della multa e dell'ammenda ai sensi del presente Capo, si applicano, in quanto compatibili e non espressamente derogate, le disposizioni del Capo III della presente legge e le ulteriori disposizioni di legge, ovunque previste, che si riferiscono alle corrispondenti pene sostitutive.))

### Art. 103-quater. - (( (Disposizioni relative ai minorenni). ))

((La pena pecuniaria, anche sostitutiva, applicata per un reato commesso da persona minore di eta', in caso di mancato pagamento si converte nel lavoro di pubblica utilita' sostitutivo, se vi e' il consenso del minore non piu' soggetto ad obbligo di istruzione. In caso contrario, si converte nella detenzione domiciliare sostitutiva. La durata della pena da conversione non puo' superare un anno, se la pena convertita e' la multa, ovvero sei mesi, se la pena convertita e' l'ammenda. Tuttavia, in caso di insolvibilita' del condannato la durata massima della pena da conversione non puo' superare sei mesi, se la pena convertita e' la multa, ovvero tre mesi, se la pena convertita e' l'ammenda. Si applicano, in quanto compatibili, gli articoli 71, 102 e 103, nonche' l'articolo 103-ter. Si applica altresi', in quanto compatibile, l'articolo 660 del codice di procedura penale. Non si applica l'articolo 103-bis e il minore, nel corso dell'esecuzione della detenzione domiciliare sostitutiva, puo' essere affidato in prova al servizio sociale ai sensi dell'articolo 5 del decreto legislativo 2 ottobre 2018, n. 121.))

### Art. 104. - (Nuovo testo degli articoli 163, 175 e 237 del codice penale)

Gli articoli 163, 175 e 237 del codice penale sono sostituiti dai seguenti: "Art. 163. - (Sospensione condizionale della pena). - Nel pronunciare sentenza di condanna alla reclusione o all'arresto per un tempo non superiore a due anni, ovvero a pena pecuniaria che, sola o congiunta alla pena detentiva e ragguagliata a norma dell'articolo 135, sia equivalente ad una pena privativa della liberta' personale per un tempo non superiore, nel complesso, a due anni, il giudice puo' ordinare che l'esecuzione della pena rimanga sospesa per il termine di cinque anni se la condanna e' per delitto e di due anni se la condanna e' per contravvenzione. Se il reato e' stato commesso da un minore degli anni diciotto, la sospensione puo' essere ordinata quando si infligga una pena restrittiva della liberta' personale non superiore a tre anni, ovvero una pena pecuniaria che, sola o congiunta alla pena detentiva e ragguagliata a norma dell'articolo 135, sia equivalente ad una pena privativa della liberta' personale per un tempo non superiore, nel complesso, a tre anni. Se il reato e' stato commesso da persona di eta' superiore agli anni diciotto ma inferiore agli anni ventuno o da chi ha compiuto gli anni settanta, la sospensione puo' essere ordinata quando si infligga una pena restrittiva della liberta' personale non superiore a due anni e sei mesi ovvero una pena pecuniaria che, sola o congiunta alla pena detentiva e ragguagliata a norma dell'articolo 135, sia equivalente ad una pena privativa della liberta' personale per un tempo non superiore, nel complesso, a due anni e sei mesi". "Art. 175. - (Non menzione della condanna nel certificato del casellario giudiziale). - Se, con una prima condanna, e' inflitta una pena detentiva non superiore a due anni, ovvero una pena pecuniaria non superiore a un milione, il giudice, avuto riguardo alle circostanze indicate nell'articolo 133, puo' ordinare in sentenza che non sia fatta menzione della condanna nel certificato del casellario giudiziale, spedito a richiesta di privati, non per ragione di diritto elettorale. La non menzione della condanna puo' essere altresi' concessa quando e' inflitta congiuntamente una pena detentiva non superiore a due anni ed una pena pecuniaria che, ragguagliata a norma dell'articolo 135 e cumulata alla pena detentiva, priverebbe complessivamente il condannato della liberta' personale per un tempo non superiore a trenta mesi. Se il condannato commette successivamente un delitto, l'ordine di non fare menzione della condanna precedente e' revocato. Le disposizioni di questo articolo non si applicano quando alla condanna conseguono pene accessorie". "Art. 237. - (Cauzione di buona condotta). - La cauzione di buona condotta e' data mediante il deposito, presso la Cassa delle ammende, di una somma non inferiore a lire duecentomila, ne' superiore a lire quattro milioni. In luogo del deposito, e' ammessa la prestazione di una garanzia mediante ipoteca o anche mediante fideiussione solidale. La durata della misura di sicurezza non puo' essere inferiore a un anno, ne' superiore a cinque, e decorre dal giorno in cui la cauzione fu prestata".

### Art. 105.

((ARTICOLO ABROGATO DAL D.LGS. 10 OTTOBRE 2022, N. 150))

### Art. 106.

((ARTICOLO ABROGATO DAL D.LGS. 10 OTTOBRE 2022, N. 150))

### Art. 107. - (( (Esecuzione delle pene conseguenti alla conversione della multa o dell'ammenda). ))

((Per l'esecuzione della semiliberta' sostitutiva, della detenzione domiciliare sostitutiva e del lavoro di pubblica utilita' sostitutivo, quali pene conseguenti alla conversione della multa o dell'ammenda, si applicano gli articoli 62, 63, 64, 65, 68 e 69. Competente e' il magistrato di sorveglianza, che provvede ai sensi dell'articolo 678, comma 1-bis, del codice di procedura penale.))

### Art. 108. - (( (Inosservanza delle prescrizioni inerenti alle pene conseguenti alla conversione della multa o della ammenda). ))

((La mancata esecuzione delle pene conseguenti alla conversione della pena pecuniaria, anche sostitutiva di una pena detentiva, ovvero la violazione grave o reiterata degli obblighi e delle prescrizioni ad esse inerenti, ne comporta la revoca e la parte residua si converte in uguale periodo di reclusione o di arresto, a seconda della specie della pena pecuniaria originariamente inflitta. La detenzione domiciliare e il lavoro di pubblica utilita', tuttavia, possono essere convertiti in altra pena sostitutiva piu' grave. Competente per la conversione e' il magistrato di sorveglianza, che provvede ai sensi dell'articolo 678, comma 1-bis, del codice di procedura penale. Si applicano, in quanto compatibili, il secondo e il terzo comma dell'articolo 66. Si applicano le disposizioni di cui al primo e al secondo comma dell'articolo 72.))

### Art. 109. - (Mancata esecuzione dolosa di sanzioni pecuniarie)

Dopo l'articolo 388-bis del codice penale e' inserito il seguente: "Art. 388-ter. - (Mancata esecuzione dolosa di sanzioni pecuniarie). - Chiunque, per sottrarsi all'esecuzione di una multa o di una ammenda o di una sanzione amministrativa pecuniaria, compie, sui propri o sugli altrui beni, atti simulati o fraudolenti, o commette allo stesso scopo altri fatti fraudolenti, e' punito, qualora non ottemperi nei termini all'ingiunzione di pagamento contenuta nel precetto, con la reclusione da sei mesi a tre anni".

### Art. 110. - (Abrogazione di norma)

E' abrogato l'articolo 49 della legge 26 luglio 1975, n. 354.

### Art. 111. - (Disposizioni transitorie)

Le norme sulla conversione delle pene pecuniarie si applicano ai reati commessi successivamente all'entrata in vigore della presente legge. In deroga a quanto disposto dall'articolo 172 del codice penale, la pena della multa inflitta, anche congiuntamente a quella della reclusione, per reati commessi prima della entrata in vigore della presente legge, si estingue col decorso del termine di dieci anni dalla data di entrata in vigore della presente legge; tuttavia, se la sentenza di condanna e divenuta irrevocabile successivamente alla data di entrata in vigore della presente legge, la pena della multa si estingue col decorso di dieci anni dal passaggio in giudicato della sentenza.

### Art. 112. - (Perdono giudiziale)

L'articolo 19 del regio decreto-legge 20 luglio 1934, n. 1404, convertito, con modificazioni, nella legge 27 maggio 1935, n. 835, e' sostituito dal seguente: "Art. 19. - (Perdono giudiziale). - Se per il reato commesso da minore degli anni diciotto il tribunale per i minorenni ritiene che si possa applicare una pena restrittiva della liberta' personale non superiore a due anni, ovvero una pena pecuniaria non superiore a lire tre milioni, anche se congiunta a detta pena, puo' applicare il perdono giudiziale, sia quando provvede a norma dell'articolo 14 sia nel giudizio".

### Art. 113. - (Aumento delle pene pecuniarie)

Le pene pecuniarie comminate per i reati previsti dal codice penale o dalle leggi speciali, nonche' le sanzioni pecuniarie comminate per le infrazioni previste dal codice di procedura penale, aumentate per effetto della legge 12 luglio 1961, n. 603, sono moltiplicate per cinque. Sono altresi' moltiplicate per cinque le pene pecuniarie comminate per reati previsti da leggi entrate in vigore dopo il 21 ottobre 1947 e prima della legge 12 luglio 1961, n. 603. Le pene pecuniarie comminate per reati previsti da leggi entrate in vigore dopo la legge 12 luglio 1961, n. 603, e fino al 31 dicembre 1970 sono moltiplicate per tre. Quelle comminate per reati previsti da leggi entrate in vigore dopo il 31 dicembre 1970 e fino al 31 dicembre 1975, ad eccezione delle leggi in materia di imposte dirette e di tasse ed imposte indirette sugli affari, sono moltiplicate per due. Quando, tenuto conto degli aumenti previsti nei commi precedenti, la legge stabilisce la pena dell'ammenda inferiore nel minimo a lire quattromila o nel massimo a lire diecimila, i limiti edittali sono elevati rispettivamente a lire diecimila e a lire venticinquemila.((4))

------------ AGGIORNAMENTO (4) La L. 24 marzo 1989, n. 122 (in G.U. 6/4/1989, n.80) ha disposto (con l'art. 20 comma 3) che:"La disposizione risultante dal combinato disposto dell'articolo 11 della legge 14 febbraio 1974, n. 62 e degli articoli 113 e 114 della legge 24 novembre 1981, n. 689, in relazione alla disposizione del quarto comma del citato articolo 11, deve essere interpretata nel senso che la somma di lire 5.000 era dovuta soltanto fino alla vigenza delle sanzioni edittali previste prima degli aumenti operati dagli stessi articolo 113 e 114."

### Art. 114. - (Aumento delle sanzioni amministrative pecuniarie)

Le disposizioni dell'articolo precedente si applicano a tutte le sanzioni amministrative pecuniarie originariamente previste come sanzioni penali. Le altre sanzioni amministrative pecuniarie inferiori nel minimo ((a euro 20)) o nel massimo ((a euro 50)) sono elevate, rispettivamente, ((a euro 20)) e ((a euro 50)). Le disposizioni dei precedenti commi si applicano anche alle violazioni finanziarie.(4)

----------- AGGIORNAMENTO (4) La L. 24 marzo 1989, n. 122 (in G.U. 6/4/1989, n.80) ha disposto (con l'art. 20 comma 3) che:"La disposizione risultante dal combinato disposto dell'articolo 11 della legge 14 febbraio 1974, n. 62 e degli articoli 113 e 114 della legge 24 novembre 1981, n. 689, in relazione alla disposizione del quarto comma del citato articolo 11, deve essere interpretata nel senso che la somma di lire 5.000 era dovuta soltanto fino alla vigenza delle sanzioni edittali previste prima degli aumenti operati dagli stessi articolo 113 e 114."

### Art. 115. - (Pene proporzionali)

Le disposizioni degli articoli 113 e 114 non si applicano alle pene e sanzioni amministrative pecuniarie quando l'ammontare delle stesse o della pena base che viene assunta per la loro determinazione non e' fissato direttamente dalla legge ma e' diversamente stabilito.

### Art. 116. - (Nuovo testo degli articoli 196 e 197 del codice penale)

Gli articoli 196 e 197 del codice penale sono sostituiti dai seguenti: "Art. 196. - (Obbligazione civile per le multe e le ammende inflitte a persona dipendente). - Nei reati commessi da chi e' soggetto all'altrui autorita', direzione o vigilanza, la persona rivestita dell'autorita', o incaricata della direzione o vigilanza, e' obbligata, in caso di insolvibilita' del condannato, al pagamento di una somma pari all'ammontare della multa o dell'ammenda inflitta al colpevole, se si tratta di violazioni di disposizioni che essa era tenuta a far osservare e delle quali non debba rispondere penalmente. Qualora la persona preposta risulti insolvibile, si applicano al condannato le disposizioni dell'articolo 136". "Art. 197. - (Obbligazione civile delle persone giuridiche per il pagamento delle multe e delle ammende). - Gli enti forniti di personalita' giuridica, eccettuati lo Stato, le regioni, le province ed i comuni, qualora sia pronunciata condanna per reato contro chi ne abbia la rappresentanza, o l'amministrazione, o sia con essi in rapporto di dipendenza, e si tratti di reato che costituisca violazione degli obblighi inerenti alla qualita' rivestita dal colpevole, ovvero sia commesso nell'interesse della persona giuridica, sono obbligati al pagamento, in caso di insolvibilita' del condannato, di una somma pari all'ammontare della multa o dell'ammenda inflitta. Se tale obbligazione non puo' essere adempiuta, si applicano al condannato le disposizioni dell'articolo 136".

### Art. 117. - (Persona civilmente obbligata per l'ammenda e per la multa)

Tutte le disposizioni processuali relative alla persona civilmente obbligata per l'ammenda si intendono riferite anche alla persona civilmente obbligata per la multa.

## DISPOSIZIONI IN MATERIA DI PENE ACCESSORIE, PRESCRIZIONE, OBLAZIONE, SOSPENSIONE CONDIZIONALE DELLA PENA E CONFISCA

### Art. 118. - (Modifiche dell'articolo 19 del codice penale, in materia di pene accessorie - Specie)

I primi due commi dell'articolo 19 del codice penale sono sostituiti dai seguenti: "Le pene accessorie per i delitti sono: 1) l'interdizione dai pubblici uffici; 2) l'interdizione da una professione o da un'arte; 3) l'interdizione legale; 4) l'interdizione dagli uffici direttivi delle persone giuridiche e delle imprese; 5) l'incapacita' di contrattare con la pubblica amministrazione; 6) la decadenza o la sospensione dall'esercizio della potesta' dei genitori. Le pene accessorie per le contravvenzioni sono: 1) la sospensione dall'esercizio di una professione o di un'arte; 2) la sospensione dagli uffici direttivi delle persone giuridiche e delle imprese".

### Art. 119. - (Modifiche dell'articolo 32 del codice penale in materia di interdizione legale)

Il secondo ed il terzo comma dell'articolo 32 del codice penale sono sostituiti dai seguenti: "La condanna all'ergastolo importa anche la decadenza dalla potesta' dei genitori. Il condannato alla reclusione per un tempo non inferiore a cinque anni e', durante la pena, in stato d'interdizione legale; la condanna produce altresi', durante la pena, la sospensione dall'esercizio della potesta' dei genitori, salvo che il giudice disponga altrimenti".

### Art. 120. - (Nuove norme in materia di interdizione temporanea dagli uffici direttivi delle persone giuridiche e delle imprese e di incapacita' di contrattare con la pubblica amministrazione)

Dopo l'articolo 32 del codice penale sono inseriti i seguenti articoli: "Art. 32-bis. - (Interdizione temporanea dagli uffici direttivi delle persone giuridiche e delle imprese). - L'interdizione dagli uffici direttivi delle persone giuridiche e delle imprese priva il condannato della capacita' di esercitare, durante l'interdizione, l'ufficio di amministratore, sindaco, liquidatore e direttore generale, nonche' ogni altro ufficio con potere di rappresentanza della persona giuridica o dell'imprenditore. Essa consegue ad ogni condanna alla reclusione non inferiore a sei mesi per delitti commessi con abuso dei poteri o violazione dei doveri inerenti all'ufficio". "Art. 32-ter. - (Incapacita' di contrattare con la pubblica amministrazione). - L'incapacita' di contrattare con la pubblica amministrazione importa il divieto di concludere contratti con la pubblica amministrazione, salvo che per ottenere le prestazioni di un pubblico servizio. Essa non puo' avere durata inferiore ad un anno ne' superiore a tre anni". "Art. 32-quater. - (Casi nei quali alla condanna consegue la incapacita' di contrattare con la pubblica amministrazione). - Ogni condanna per i delitti previsti dagli articoli 317, 318, 319, 320, 321, 353, 355, 356, 416, 437, 501, 501-bis, 640, n. 1 del capoverso, commessi a causa o in occasione dell'esercizio di un'attivita' imprenditoriale, importa l'incapacita' di contrattare con la pubblica amministrazione".

### Art. 121. - (Modifica dell'articolo 33 del codice penale in materia di condanna per delitto colposo)

Il primo comma dell'articolo 33 del codice penale e' sostituito dal seguente: "Le disposizioni dell'articolo 29 e del secondo capoverso dell'articolo 32 non si applicano nel caso di condanna per delitto colposo".

### Art. 122. - (Decadenza dalla potesta' dei genitori e sospensione dal suo esercizio)

L'articolo 34 del codice penale e' sostituito dal seguente: "Art. 34. - (Decadenza dalla potesta' dei genitori e sospensione dall'esercizio di essa). - La legge determina i casi nei quali la condanna importa la decadenza dalla potesta' dei genitori. La condanna per delitti commessi con abuso della potesta' dei genitori importa la sospensione dall'esercizio di essa per un periodo di tempo pari al doppio della pena inflitta. La decadenza dalla potesta' dei genitori importa anche la privazione di ogni diritto che al genitore spetti sui beni del figlio in forza della potesta' di cui al titolo IX del libro I del codice civile. La sospensione dall'esercizio della potesta' dei genitori importa anche l'incapacita' di esercitare, durante la sospensione, qualsiasi diritto che al genitore spetti sui beni del figlio in base alle norme del titolo IX del libro I del codice civile".

### Art. 123. - (Sospensione dall'esercizio degli uffici direttivi delle persone giuridiche e delle imprese)

Dopo l'articolo 35 del codice penale e' inserito il seguente: "Art. 35-bis. - (Sospensione dall'esercizio degli uffici direttivi delle persone giuridiche e delle imprese). - La sospensione dall'esercizio degli uffici direttivi delle persone giuridiche e delle imprese priva il condannato della capacita' di esercitare, durante la sospensione, l'ufficio di amministratore, sindaco, liquidatore e direttore generale, nonche' ogni altro ufficio con potere di rappresentanza della persona giuridica o dell'imprenditore. Essa non puo' avere una durata inferiore a quindici giorni ne' superiore a due anni e consegue ad ogni condanna all'arresto per contravvenzioni commesse con abuso dei poteri o violazione dei doveri inerenti all'ufficio".

### Art. 124. - (Applicazione provvisoria di pene accessorie)

L'articolo 140 del codice penale e' sostituito dal seguente: "Art. 140. - (Applicazione provvisoria di pene accessorie). - Il giudice, durante la istruzione, nei procedimenti per reati per i quali, in caso di condanna, puo' essere applicata una pena accessoria, puo' disporne in via provvisoria l'applicazione quando sussistano specificate, inderogabili esigenze istruttorie o sia necessario impedire che il reato venga portato a conseguenze ulteriori. L'interdizione dai pubblici uffici puo' essere applicata provvisoriamente solo nei procedimenti per reati commessi con abuso dei poteri o con violazione dei doveri inerenti a una pubblica funzione o ad un pubblico servizio o a taluno degli uffici indicati nel n. 3 del capoverso dell'articolo 28. La sospensione provvisoria non si applica agli uffici elettivi ricoperti per diretta investitura popolare. La pena accessoria provvisoriamente applicata non puo' avere durata superiore alla meta' della durata massima prevista dalla legge ed e' computata nella durata della pena accessoria conseguente alla condanna".

### Art. 125. - (Modifica dell'articolo 157 del codice penale in materia di prescrizione e tempo necessario a prescrivere)

Il numero 6 del primo comma dell'articolo 157 del codice penale e' sostituito dal seguente: "6) in due anni, se si tratta di contravvenzione per cui la legge stabilisce la pena dell'ammenda".

### Art. 126. - (Oblazione nelle contravvenzioni punite con pene alternative)

Dopo l'articolo 162 del codice penale e' inserito il seguente: "Art. 162-bis. - (Oblazione nelle contravvenzioni punite con pene alternative). - Nelle contravvenzioni per le quali la legge stabilisce la pena alternativa dell'arresto o dell'ammenda, il contravventore puo' essere ammesso a pagare, prima dell'apertura del dibattimento, ovvero prima del decreto di condanna, una somma corrispondente alla meta' del massimo dell'ammenda stabilita dalla legge per la contravvenzione commessa oltre le spese del procedimento. Con la domanda di oblazione il contravventore deve depositare la somma corrispondente alla meta' del massimo dell'ammenda. L'oblazione non e' ammessa quando ricorrono i casi previsti dal terzo capoverso dell'articolo 99, dall'articolo 104 o dall'articolo 105, ne' quando permangono conseguenze dannose o pericolose del reato eliminabili da parte del contravventore. In ogni altro caso il giudice puo' respingere con ordinanza la domanda di oblazione, avuto riguardo alla gravita' del fatto. La domanda puo' essere riproposta sino all'inizio della discussione finale del dibattimento di primo grado. Il pagamento delle somme indicate nella prima parte del presente articolo estingue il reato".

### Art. 127. - (Applicazione di norme)

Le disposizioni dell'articolo 162-bis del codice penale si applicano anche ai reati indicati nelle lettere f), h), i), n) del primo comma dell'articolo 34.

### Art. 128. - (Obblighi del condannato)

L'articolo 165 del codice penale e' sostituito dal seguente: "Art. 165. - (Obblighi del condannato). - La sospensione condizionale della pena puo' essere subordinata all'adempimento dell'obbligo delle restituzioni, al pagamento della somma liquidata a titolo di risarcimento del danno o provvisoriamente assegnata sull'ammontare di esso e alla pubblicazione della sentenza a titolo di riparazione del danno; puo' altresi' essere subordinata, salvo che la legge disponga altrimenti, all'eliminazione delle conseguenze dannose o pericolose del reato, secondo le modalita' indicate dal giudice nella sentenza di condanna. La sospensione condizionale della pena, quando e' concessa a persona che ne ha gia' usufruito, deve essere subordinata all'adempimento di uno degli obblighi previsti nel comma precedente, salvo che cio' sia impossibile. Il giudice nella sentenza stabilisce il termine entro il quale gli obblighi devono essere adempiuti".

### Art. 129. - (Inosservanza di pene accessorie)

L'articolo 389 del codice penale e' sostituito dal seguente: "Art. 389. - (Inosservanza di pene accessorie). - Chiunque, avendo riportato una condanna da cui consegue una pena accessoria, trasgredisce agli obblighi o ai divieti inerenti a tale pena, e' punito con la reclusione da due a sei mesi. La stessa pena si applica a chi trasgredisce agli obblighi o ai divieti inerenti ad una pena accessoria provvisoriamente applicata".

### Art. 130. - (Modifiche dell'articolo 200 del codice di procedura penale in materia di impugnazione di ordinanze emesse in giudizio)

Dopo il primo comma dell'articolo 200 del codice di procedura penale e' inserito il seguente: "L'impugnazione dell'ordinanza che decide sulla domanda di oblazione puo' essere proposta soltanto con l'impugnazione contro la sentenza".

### Art. 131. - (Applicazione provvisoria di pene accessorie o di misure di sicurezza)

L'articolo 301 del codice di procedura penale e' sostituito dal seguente: "Art. 301. - (Applicazione provvisoria di pene accessorie o di misure di sicurezza). - L'applicazione provvisoria delle pene accessorie, nei casi consentiti dalla legge, e' disposta dal giudice, anche d'ufficio, con decreto motivato, in qualunque stato dell'istruzione, dopo l'interrogatorio dell'imputato o, se questo non e' possibile, dopo la emissione di un mandato. Il decreto e' immediatamente comunicato al pubblico ministero per l'esecuzione. Le stesse disposizioni si osservano per l'applicazione provvisoria delle misure di sicurezza. Contro il provvedimento del giudice istruttore che dispone l'applicazione provvisoria della pena accessoria o della misura di sicurezza o che non accoglie la richiesta del pubblico ministero, il procuratore della Repubblica, il procuratore generale e l'imputato possono proporre appello dinanzi alla sezione istruttoria della corte di appello. Contro il provvedimento emesso dalla sezione istruttoria puo' essere proposto ricorsa per cassazione. L'impugnazione non sospende l'esecuzione del provvedimento".

### Art. 132. - (Modificazioni dell'articolo 400 del codice di procedura penale in materia di provvedimenti per l'applicazione provvisoria di pene accessorie o di misure di sicurezza)

Dopo l'ultimo comma dell'articolo 400 del codice di procedura penale sono aggiunti i seguenti commi: "Si applicano le disposizioni previste dal terzo, quarto ed ultimo comma dell'articolo 301; contro il provvedimento emesso dal pretore l'appello e' proposto dinanzi al giudice istruttore; contro la decisione emessa dal giudice istruttore in grado di appello puo' essere proposto ricorso per cassazione. L'impugnazione non sospende l'esecuzione del provvedimento".

### Art. 133. - (Esecuzione provvisoria di misure di sicurezza)

L'articolo 485 del codice di procedura penale e' sostituito dal seguente: "Art. 485. - (Esecuzione provvisoria di misure di sicurezza). - Il giudice, quando abbia disposto una misura di sicurezza, puo', nei casi consentiti dall'articolo 206 del codice penale, ordinarne con la sentenza la provvisoria esecuzione. La sentenza e' impugnabile anche per il capo che dispone l'esecuzione provvisoria della misura di sicurezza; ma l'impugnazione non ne sospende l'esecuzione".

### Art. 134. - (Appello contro sentenze del pretore)

L'articolo 512 del codice di procedura penale e' sostituito dal seguente: "Art. 512. (Appello contro sentenze del pretore). - Contro le sentenze del pretore possono appellare al tribunale: 1) l'imputato nel caso di condanna per delitto o per contravvenzione punita con pena alternativa o per la quale non e' ammessa la oblazione ovvero quando e' stato dichiarato contravventore abituale o professionale; 2) l'imputato nel caso di proscioglimento da delitto o da contravvenzione per la quale la legge stabilisce la pena dell'arresto, qualora il proscioglimento sia pronunciato per estinzione del reato a seguito di giudizio di comparazione tra circostanze o per insufficienza di prove o per concessione del perdono giudiziale ovvero perche' si tratta di persona non imputabile o di persona non punibile perche' il fatto non costituisce reato, se e' stata applicata o puo', con provvedimento successivo, essere applicata una misura di sicurezza; 3) il rappresentante del pubblico ministero nel dibattimento davanti al pretore e il procuratore della Repubblica nel caso di proscioglimento, se l'imputazione riguardava un delitto o una contravvenzione punibile con l'arresto; e nel caso di condanna per delitto ovvero per contravvenzione punita con pena alternativa o per la quale non e' ammessa l'oblazione".

### Art. 135. - (Appello contro sentenze del tribunale e della corte d'assise)

L'articolo 513 del codice di procedura penale e' sostituito dal seguente: "Art. 513. - (Appello contro sentenze del tribunale e della corte di assise). - Contro le sentenze del tribunale e della corte di assise possono appellare, rispettivamente, alla corte di appello e alla corte di assise di appello, salvo che la legge disponga altrimenti: 1) l'imputato nel caso di condanna per delitto o per contravvenzione punita con pena alternativa o per la quale non e' ammessa la oblazione ovvero quando e' stato dichiarato contravventore abituale o professionale; 2) l'imputato nel caso di proscioglimento da delitto o da contravvenzione per la quale la legge stabilisce la pena dell'arresto, qualora il proscioglimento sia pronunziato per estinzione del reato a seguito di giudizio di comparazione tra circostanze o per insufficienza di prove o per perdono giudiziale ovvero perche' si tratta di persona non imputabile o di persona non punibile perche' il fatto non costituisce reato, se e' stata applicata o puo', con provvedimento successivo, essere applicata una misura di sicurezza; 3) il procuratore della Repubblica e il procuratore generale presso la corte di appello nel caso di proscioglimento, se la imputazione riguardava un delitto o una contravvenzione punibile con l'arresto, e nel caso di condanna per delitto ovvero per contravvenzione punita con pena alternativa o per la quale non e' ammessa la oblazione".

### Art. 136. - Modifiche dell'articolo 522 del codice di procedura penale in materia di questioni di nullit

All'articolo 522 del codice di procedura penale e' aggiunto in fine il seguente comma: "Quando il giudice di primo grado ha respinto la domanda di oblazione, il giudice di appello, se riconosce erronea tale decisione, accoglie la domanda e sospende il dibattimento fissando un termine massimo non superiore a dieci giorni per il pagamento delle somme dovute. Se il pagamento avviene nel termine, il giudice di appello pronuncia sentenza di proscioglimento".

### Art. 137. - (Modifiche dell'articolo 604 del codice di procedura penale in materia di provvedimenti da iscrivere nel casellario)

Nell'articolo 604 del codice di procedura penale, al capoverso del numero 1, dopo le parole: "Non sono iscritti nel casellario giudiziale: le sentenze e i decreti di condanna concernenti contravvenzioni per le quali e' ammessa la definizione in via amministrativa o l'oblazione, salvo che", sono inserite le seguenti: "si tratti di contravvenzioni punite con la pena alternativa dell'arresto o dell'ammenda o che".

### Art. 138. - (Modifiche alle disposizioni di attuazione, di coordinamento e transitorie del codice di procedura penale)

Dopo l'articolo 48 delle disposizioni di attuazione del codice di procedura penale, approvate con regio decreto 28 maggio 1931, n. 602, sono inseriti i seguenti articoli: "Art. 48-bis. - Quando sono state sequestrate cose che possono essere restituite previa esecuzione di specifiche prescrizioni, il giudice, se l'interessato consente, ne ordina la restituzione impartendo le prescrizioni del caso ed imponendo una idonea cauzione o malleveria a garanzia della esecuzione delle prescrizioni nel termine stabilito. Scaduto il termine, se le prescrizioni non sono adempiute, il giudice provvede ai sensi dell'ultimo capoverso dell'articolo 345 del codice di procedura penale". "Art. 48-ter. - Nei casi previsti dall'ultimo capoverso dell'articolo 345 e dal primo capoverso dell'articolo 625 del codice di procedura penale, il giudice, prima di ordinare la vendita o la distruzione delle cose sequestrate, dispone, osservate le formalita' di cui agli articoli 304-bis e 304-ter del codice di prosedura penale, il prelievo di campioni, quando cio' e' possibile ed utile per l'ulteriore corso del procedimento".

### Art. 139. - (Modifica dell'articolo 116 delle norme sugli assegni bancari, circolari e su titoli speciali dell'istituto di emissione, e dei Banchi di Napoli e di Sicilia)

Nell'articolo 116 del regio decreto 21 dicembre 1933, n. 1736, dopo il primo comma e' inserito il seguente: "Nei casi piu' gravi la condanna per uno dei delitti previsti nei numeri 1 e 2 del comma precedente importa, indipendentemente dall'applicazione dell'articolo 69 del codice penale, la pubblicazione della sentenza di condanna e il divieto di emettere assegni bancari o postali per un periodo da uno a tre anni".

### Art. 140. - (Disposizioni aggiuntive alle norme in materia di assegni bancari, circolari e su titoli speciali dell'istituto di emissione, e dei Banchi di Napoli e di Sicilia)

Dopo l'articolo 116 del regio decreto 21 dicembre 1933, n. 1736, e' inserito il seguente: "Art. 116-bis - Chiunque, avendo riportato la pena accessoria prevista dall'articolo precedente, trasgredisce agli obblighi ad essa inerenti e' punito, per il solo fatto dell'emissione dell'assegno, ai sensi dell'articolo 389 del codice penale. Si applica la reclusione da sei mesi a due anni e la multa da lire centomila a lire due milioni, a chi, violando il divieto di emettere assegni bancari e postali, commette uno dei delitti previsti dai numeri 1 e 2 del primo comma dell'articolo precedente. La condanna importa la pubblicazione della sentenza e il divieto di emettere assegni bancari e postali per la durata di due anni".

### Art. 141. - (Ulteriori disposizioni aggiuntive alle norme in materia di assegni bancari, circolari e su titoli speciali dell'istituto di emissione, e dei Banchi di Napoli e di Sicilia)

Dopo l'articolo 123 del regio decreto 21 dicembre 1933, n. 1736, sono inseriti i seguenti articoli: "Art. 124. - All'atto del rilascio di moduli di assegno bancario o postale il dipendente responsabile fa sottoscrivere al richiedente una dichiarazione dalla quale risulta che lo stesso non e' interdetto dall'emissione di assegni bancari o postali. Il richiedente che dichiara il falso e' punito con la reclusione da sei mesi a due anni". "Art. 125. - Il dipendente che consegna moduli di assegno bancario o postale senza farsi rilasciare la dichiarazione prevista nell'articolo precedente e' punito, salvo che il fatto costituisca un piu' grave reato, con l'arresto da due a sei mesi o con l'ammenda da lire duecentomila a lire cinquecentomila. Il dipendente che consegna moduli di assegno bancario o postale a chi abbia dichiarato di essere stato interdetto dalla emissione di assegni bancari o postali, e' punito, salvo che il fatto costituisca piu' grave reato, con la reclusione da sei mesi a due anni".

### Art. 142. - (Modifiche al testo unico delle norme sulla circolazione stradale)

Dopo l'articolo 80 del testo unico delle norme sulla circolazione stradale, approvato con decreto del Presidente della Repubblica 15 giugno 1959, n. 393, modificato dall'articolo 2 della legge 14 febbraio 1974, n. 62, sono inseriti i seguenti articoli: "Art. 80-bis. - (Confisca e sequestro del veicolo). - Con la sentenza di condanna per i reati previsti dal dodicesimo al quattordicesimo comma dell'articolo precedente il giudice ordina la confisca del veicolo, salvo che esso appartenga a persona estranea al reato. L'autorita' giudiziaria competente e, in caso di flagranza, anche gli ufficiali e gli agenti di polizia giudiziaria devono procedere al sequestro del veicolo, osservando le norme sulla istruzione formale". "Art. 80-ter. - (Pena accessoria). - Con la sentenza di condanna per il reato previsto dal dodicesimo comma dell'articolo 80 il giudice, quando non sia possibile ordinare la confisca del veicolo, dispone la sospensione della patente di guida del condannato per la stessa durata della pena principale".

### Art. 143. - (Disposizioni aggiuntive alla legge sulla disciplina degli stupefacenti e sostanze psicotrope)

Dopo l'articolo 80 della legge 22 dicembre 1975, n. 685, e' inserito il seguente: "Art. 80-bis. - (Destinazione delle sostanze confiscate dal giudice e confiscabili dal Ministro della sanita'). - Le sostanze confiscate e quelle da confiscare in base all'articolo precedente sono immediatamente versate al Ministero della sanita'".

### Art. 144. - (Modifica alla legge recante norme per la tutela delle acque dall'inquinamento)

Al terzo comma dell'articolo 21 della legge 10 maggio 1976, n. 319, e' aggiunto in fine il seguente periodo: "La condanna importa la incapacita' di contrattare con la pubblica amministrazione".

### Art. 145.

((ARTICOLO ABROGATO DAL D.P.R. 31 MARZO 1988, N.148))

### Art. 146. - (Norma di coordinamento)

Ogniqualvolta nel codice penale o in altre leggi ricorre l'espressione "patria potesta'", la medesima e' sostituita dalla espressione "potesta' dei genitori".

### Art. 147. - (Modifica dell'articolo 2638 del codice civile in materia di accettazione di retribuzione non dovuta da parte di amministratore giudiziario o commissario governativo)

Il secondo comma dell'articolo 2638 del codice civile e' sostituito dal seguente: "Nei casi piu' gravi puo' inoltre essere disposta l'interdizione dagli uffici direttivi delle persone giuridiche e delle imprese".

### Art. 148. - (Disposizioni abrogative e di coordinamento)

L'articolo 2641 del codice civile e' abrogato. Quando nelle leggi speciali e' richiamato l'articolo 2641 del codice civile tale richiamo si intende operato all'articolo 32-bis del codice penale.

